/* errors.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from errors.vala, do not modify */

/*
 * Seahorse
 *
 * Copyright (C) 2016 Niels De Graef
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see
 * <http://www.gnu.org/licenses/>.
 */

#include "seahorse-ssh.h"

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

GQuark
seahorse_ssh_error_quark (void)
{
	return g_quark_from_static_string ("seahorse-ssh-error-quark");
}

 G_GNUC_NO_INLINE static GType
seahorse_ssh_error_get_type_once (void)
{
	static const GEnumValue values[] = {{SEAHORSE_SSH_ERROR_GENERAL, "SEAHORSE_SSH_ERROR_GENERAL", "general"}, {0, NULL, NULL}};
	GType seahorse_ssh_error_type_id;
	seahorse_ssh_error_type_id = g_enum_register_static ("SeahorseSshError", values);
	return seahorse_ssh_error_type_id;
}

GType
seahorse_ssh_error_get_type (void)
{
	static volatile gsize seahorse_ssh_error_type_id__once = 0;
	if (g_once_init_enter (&seahorse_ssh_error_type_id__once)) {
		GType seahorse_ssh_error_type_id;
		seahorse_ssh_error_type_id = seahorse_ssh_error_get_type_once ();
		g_once_init_leave (&seahorse_ssh_error_type_id__once, seahorse_ssh_error_type_id);
	}
	return seahorse_ssh_error_type_id__once;
}

