/* seahorse-common.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __COMMON_SEAHORSE_COMMON_H__
#define __COMMON_SEAHORSE_COMMON_H__

#include <gio/gio.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gcr/gcr-base.h>
#include <gdk/gdk.h>
#include <handy.h>
#include "pgp/seahorse-server-source.h"

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define SEAHORSE_BAD_FILENAME_CHARS "/\\<>|:?;"
#define SEAHORSE_ICON_KEY "seahorse-key"
#define SEAHORSE_ICON_SECRET "seahorse-key-personal"
#define SEAHORSE_ICON_KEY_SSH "seahorse-key-ssh"
#define SEAHORSE_ICON_SIGN "seahorse-sign"
#define SEAHORSE_ICON_SIGN_OK "seahorse-sign-ok"
#define SEAHORSE_ICON_SIGN_BAD "seahorse-sign-bad"
#define SEAHORSE_ICON_SIGN_UNKNOWN "seahorse-sign-unknown"
#define SEAHORSE_ICON_WEBBROWSER "web-browser"
#define SEAHORSE_ICON_FOLDER "folder"
#define SEAHORSE_ICON_PASSWORD "gcr-password"
#define SEAHORSE_PASS_BAD 0x00000001
#define SEAHORSE_PASS_NEW 0x01000000

#define SEAHORSE_TYPE_ACTION_GROUP (seahorse_action_group_get_type ())
#define SEAHORSE_ACTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_ACTION_GROUP, SeahorseActionGroup))
#define SEAHORSE_ACTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_ACTION_GROUP, SeahorseActionGroupClass))
#define SEAHORSE_IS_ACTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_ACTION_GROUP))
#define SEAHORSE_IS_ACTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_ACTION_GROUP))
#define SEAHORSE_ACTION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_ACTION_GROUP, SeahorseActionGroupClass))

typedef struct _SeahorseActionGroup SeahorseActionGroup;
typedef struct _SeahorseActionGroupClass SeahorseActionGroupClass;
typedef struct _SeahorseActionGroupPrivate SeahorseActionGroupPrivate;

#define SEAHORSE_TYPE_CATALOG (seahorse_catalog_get_type ())
#define SEAHORSE_CATALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_CATALOG, SeahorseCatalog))
#define SEAHORSE_CATALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_CATALOG, SeahorseCatalogClass))
#define SEAHORSE_IS_CATALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_CATALOG))
#define SEAHORSE_IS_CATALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_CATALOG))
#define SEAHORSE_CATALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_CATALOG, SeahorseCatalogClass))

typedef struct _SeahorseCatalog SeahorseCatalog;
typedef struct _SeahorseCatalogClass SeahorseCatalogClass;

#define SEAHORSE_TYPE_ADD_KEYSERVER_DIALOG (seahorse_add_keyserver_dialog_get_type ())
#define SEAHORSE_ADD_KEYSERVER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_ADD_KEYSERVER_DIALOG, SeahorseAddKeyserverDialog))
#define SEAHORSE_ADD_KEYSERVER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_ADD_KEYSERVER_DIALOG, SeahorseAddKeyserverDialogClass))
#define SEAHORSE_IS_ADD_KEYSERVER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_ADD_KEYSERVER_DIALOG))
#define SEAHORSE_IS_ADD_KEYSERVER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_ADD_KEYSERVER_DIALOG))
#define SEAHORSE_ADD_KEYSERVER_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_ADD_KEYSERVER_DIALOG, SeahorseAddKeyserverDialogClass))

typedef struct _SeahorseAddKeyserverDialog SeahorseAddKeyserverDialog;
typedef struct _SeahorseAddKeyserverDialogClass SeahorseAddKeyserverDialogClass;
typedef struct _SeahorseAddKeyserverDialogPrivate SeahorseAddKeyserverDialogPrivate;

#define SEAHORSE_TYPE_APP_SETTINGS (seahorse_app_settings_get_type ())
#define SEAHORSE_APP_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_APP_SETTINGS, SeahorseAppSettings))
#define SEAHORSE_APP_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_APP_SETTINGS, SeahorseAppSettingsClass))
#define SEAHORSE_IS_APP_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_APP_SETTINGS))
#define SEAHORSE_IS_APP_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_APP_SETTINGS))
#define SEAHORSE_APP_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_APP_SETTINGS, SeahorseAppSettingsClass))

typedef struct _SeahorseAppSettings SeahorseAppSettings;
typedef struct _SeahorseAppSettingsClass SeahorseAppSettingsClass;
typedef struct _SeahorseAppSettingsPrivate SeahorseAppSettingsPrivate;

#define SEAHORSE_TYPE_BACKEND (seahorse_backend_get_type ())
#define SEAHORSE_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_BACKEND, SeahorseBackend))
#define SEAHORSE_IS_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_BACKEND))
#define SEAHORSE_BACKEND_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SEAHORSE_TYPE_BACKEND, SeahorseBackendIface))

typedef struct _SeahorseBackend SeahorseBackend;
typedef struct _SeahorseBackendIface SeahorseBackendIface;

#define SEAHORSE_TYPE_PLACE (seahorse_place_get_type ())
#define SEAHORSE_PLACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_PLACE, SeahorsePlace))
#define SEAHORSE_IS_PLACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_PLACE))
#define SEAHORSE_PLACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SEAHORSE_TYPE_PLACE, SeahorsePlaceIface))

typedef struct _SeahorsePlace SeahorsePlace;
typedef struct _SeahorsePlaceIface SeahorsePlaceIface;
typedef enum  {
	SEAHORSE_PLACE_CATEGORY_PASSWORDS,
	SEAHORSE_PLACE_CATEGORY_KEYS,
	SEAHORSE_PLACE_CATEGORY_CERTIFICATES
} SeahorsePlaceCategory;

#define SEAHORSE_PLACE_TYPE_CATEGORY (seahorse_place_category_get_type ())
typedef struct _SeahorseCatalogPrivate SeahorseCatalogPrivate;

#define SEAHORSE_TYPE_DATE_PICKER (seahorse_date_picker_get_type ())
#define SEAHORSE_DATE_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_DATE_PICKER, SeahorseDatePicker))
#define SEAHORSE_DATE_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_DATE_PICKER, SeahorseDatePickerClass))
#define SEAHORSE_IS_DATE_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_DATE_PICKER))
#define SEAHORSE_IS_DATE_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_DATE_PICKER))
#define SEAHORSE_DATE_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_DATE_PICKER, SeahorseDatePickerClass))

typedef struct _SeahorseDatePicker SeahorseDatePicker;
typedef struct _SeahorseDatePickerClass SeahorseDatePickerClass;
typedef struct _SeahorseDatePickerPrivate SeahorseDatePickerPrivate;

#define SEAHORSE_TYPE_DELETABLE (seahorse_deletable_get_type ())
#define SEAHORSE_DELETABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_DELETABLE, SeahorseDeletable))
#define SEAHORSE_IS_DELETABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_DELETABLE))
#define SEAHORSE_DELETABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SEAHORSE_TYPE_DELETABLE, SeahorseDeletableIface))

typedef struct _SeahorseDeletable SeahorseDeletable;
typedef struct _SeahorseDeletableIface SeahorseDeletableIface;

#define SEAHORSE_TYPE_DELETER (seahorse_deleter_get_type ())
#define SEAHORSE_DELETER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_DELETER, SeahorseDeleter))
#define SEAHORSE_DELETER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_DELETER, SeahorseDeleterClass))
#define SEAHORSE_IS_DELETER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_DELETER))
#define SEAHORSE_IS_DELETER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_DELETER))
#define SEAHORSE_DELETER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_DELETER, SeahorseDeleterClass))

typedef struct _SeahorseDeleter SeahorseDeleter;
typedef struct _SeahorseDeleterClass SeahorseDeleterClass;

#define SEAHORSE_TYPE_DELETE_DIALOG (seahorse_delete_dialog_get_type ())
#define SEAHORSE_DELETE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_DELETE_DIALOG, SeahorseDeleteDialog))
#define SEAHORSE_DELETE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_DELETE_DIALOG, SeahorseDeleteDialogClass))
#define SEAHORSE_IS_DELETE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_DELETE_DIALOG))
#define SEAHORSE_IS_DELETE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_DELETE_DIALOG))
#define SEAHORSE_DELETE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_DELETE_DIALOG, SeahorseDeleteDialogClass))

typedef struct _SeahorseDeleteDialog SeahorseDeleteDialog;
typedef struct _SeahorseDeleteDialogClass SeahorseDeleteDialogClass;
typedef struct _SeahorseDeleteDialogPrivate SeahorseDeleteDialogPrivate;
typedef struct _SeahorseDeleterPrivate SeahorseDeleterPrivate;

#define SEAHORSE_TYPE_EXPORTABLE (seahorse_exportable_get_type ())
#define SEAHORSE_EXPORTABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_EXPORTABLE, SeahorseExportable))
#define SEAHORSE_IS_EXPORTABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_EXPORTABLE))
#define SEAHORSE_EXPORTABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SEAHORSE_TYPE_EXPORTABLE, SeahorseExportableIface))

typedef struct _SeahorseExportable SeahorseExportable;
typedef struct _SeahorseExportableIface SeahorseExportableIface;
typedef enum  {
	SEAHORSE_EXPORTER_TYPE_ANY,
	SEAHORSE_EXPORTER_TYPE_TEXTUAL
} SeahorseExporterType;

#define SEAHORSE_TYPE_EXPORTER_TYPE (seahorse_exporter_type_get_type ())

#define SEAHORSE_TYPE_EXPORTER (seahorse_exporter_get_type ())
#define SEAHORSE_EXPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_EXPORTER, SeahorseExporter))
#define SEAHORSE_IS_EXPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_EXPORTER))
#define SEAHORSE_EXPORTER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SEAHORSE_TYPE_EXPORTER, SeahorseExporterIface))

typedef struct _SeahorseExporter SeahorseExporter;
typedef struct _SeahorseExporterIface SeahorseExporterIface;

#define SEAHORSE_TYPE_INTERACTION (seahorse_interaction_get_type ())
#define SEAHORSE_INTERACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_INTERACTION, SeahorseInteraction))
#define SEAHORSE_INTERACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_INTERACTION, SeahorseInteractionClass))
#define SEAHORSE_IS_INTERACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_INTERACTION))
#define SEAHORSE_IS_INTERACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_INTERACTION))
#define SEAHORSE_INTERACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_INTERACTION, SeahorseInteractionClass))

typedef struct _SeahorseInteraction SeahorseInteraction;
typedef struct _SeahorseInteractionClass SeahorseInteractionClass;
typedef struct _SeahorseInteractionPrivate SeahorseInteractionPrivate;

#define SEAHORSE_TYPE_ITEM_LIST (seahorse_item_list_get_type ())
#define SEAHORSE_ITEM_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_ITEM_LIST, SeahorseItemList))
#define SEAHORSE_ITEM_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_ITEM_LIST, SeahorseItemListClass))
#define SEAHORSE_IS_ITEM_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_ITEM_LIST))
#define SEAHORSE_IS_ITEM_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_ITEM_LIST))
#define SEAHORSE_ITEM_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_ITEM_LIST, SeahorseItemListClass))

typedef struct _SeahorseItemList SeahorseItemList;
typedef struct _SeahorseItemListClass SeahorseItemListClass;
typedef struct _SeahorseItemListPrivate SeahorseItemListPrivate;
typedef enum  {
	SEAHORSE_ITEM_LIST_SHOW_FILTER_ANY,
	SEAHORSE_ITEM_LIST_SHOW_FILTER_PERSONAL,
	SEAHORSE_ITEM_LIST_SHOW_FILTER_TRUSTED
} SeahorseItemListShowFilter;

#define SEAHORSE_ITEM_LIST_TYPE_SHOW_FILTER (seahorse_item_list_show_filter_get_type ())

#define SEAHORSE_TYPE_LOCKABLE (seahorse_lockable_get_type ())
#define SEAHORSE_LOCKABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_LOCKABLE, SeahorseLockable))
#define SEAHORSE_IS_LOCKABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_LOCKABLE))
#define SEAHORSE_LOCKABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SEAHORSE_TYPE_LOCKABLE, SeahorseLockableIface))

typedef struct _SeahorseLockable SeahorseLockable;
typedef struct _SeahorseLockableIface SeahorseLockableIface;

#define SEAHORSE_TYPE_OBJECT (seahorse_object_get_type ())
#define SEAHORSE_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_OBJECT, SeahorseObject))
#define SEAHORSE_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_OBJECT, SeahorseObjectClass))
#define SEAHORSE_IS_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_OBJECT))
#define SEAHORSE_IS_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_OBJECT))
#define SEAHORSE_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_OBJECT, SeahorseObjectClass))

typedef struct _SeahorseObject SeahorseObject;
typedef struct _SeahorseObjectClass SeahorseObjectClass;
typedef struct _SeahorseObjectPrivate SeahorseObjectPrivate;
typedef enum  {
	SEAHORSE_FLAG_NONE = 0,
	SEAHORSE_FLAG_IS_VALID = 0x00000001,
	SEAHORSE_FLAG_CAN_ENCRYPT = 0x00000002,
	SEAHORSE_FLAG_CAN_SIGN = 0x00000004,
	SEAHORSE_FLAG_CAN_CERTIFY = 0x00000008,
	SEAHORSE_FLAG_CAN_AUTHENTICATE = 0x00000010,
	SEAHORSE_FLAG_EXPIRED = 0x00000100,
	SEAHORSE_FLAG_REVOKED = 0x00000200,
	SEAHORSE_FLAG_DISABLED = 0x00000400,
	SEAHORSE_FLAG_TRUSTED = 0x00001000,
	SEAHORSE_FLAG_PERSONAL = 0x00002000,
	SEAHORSE_FLAG_EXPORTABLE = 0x00100000,
	SEAHORSE_FLAG_DELETABLE = 0x10000000
} SeahorseFlags;

#define SEAHORSE_TYPE_FLAGS (seahorse_flags_get_type ())
typedef enum  {
	SEAHORSE_USAGE_NONE = 0,
	SEAHORSE_USAGE_SYMMETRIC_KEY = 1,
	SEAHORSE_USAGE_PUBLIC_KEY = 2,
	SEAHORSE_USAGE_PRIVATE_KEY = 3,
	SEAHORSE_USAGE_CREDENTIALS = 4,
	SEAHORSE_USAGE_IDENTITY = 5,
	SEAHORSE_USAGE_OTHER = 10
} SeahorseUsage;

#define SEAHORSE_TYPE_USAGE (seahorse_usage_get_type ())

#define SEAHORSE_TYPE_PASSPHRASE_PROMPT (seahorse_passphrase_prompt_get_type ())
#define SEAHORSE_PASSPHRASE_PROMPT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_PASSPHRASE_PROMPT, SeahorsePassphrasePrompt))
#define SEAHORSE_PASSPHRASE_PROMPT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_PASSPHRASE_PROMPT, SeahorsePassphrasePromptClass))
#define SEAHORSE_IS_PASSPHRASE_PROMPT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_PASSPHRASE_PROMPT))
#define SEAHORSE_IS_PASSPHRASE_PROMPT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_PASSPHRASE_PROMPT))
#define SEAHORSE_PASSPHRASE_PROMPT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_PASSPHRASE_PROMPT, SeahorsePassphrasePromptClass))

typedef struct _SeahorsePassphrasePrompt SeahorsePassphrasePrompt;
typedef struct _SeahorsePassphrasePromptClass SeahorsePassphrasePromptClass;
typedef struct _SeahorsePassphrasePromptPrivate SeahorsePassphrasePromptPrivate;

#define SEAHORSE_TYPE_PGP_SETTINGS (seahorse_pgp_settings_get_type ())
#define SEAHORSE_PGP_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_PGP_SETTINGS, SeahorsePgpSettings))
#define SEAHORSE_PGP_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_PGP_SETTINGS, SeahorsePgpSettingsClass))
#define SEAHORSE_IS_PGP_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_PGP_SETTINGS))
#define SEAHORSE_IS_PGP_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_PGP_SETTINGS))
#define SEAHORSE_PGP_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_PGP_SETTINGS, SeahorsePgpSettingsClass))

typedef struct _SeahorsePgpSettings SeahorsePgpSettings;
typedef struct _SeahorsePgpSettingsClass SeahorsePgpSettingsClass;
typedef struct _SeahorsePgpSettingsPrivate SeahorsePgpSettingsPrivate;

#define SEAHORSE_TYPE_PREFS (seahorse_prefs_get_type ())
#define SEAHORSE_PREFS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_PREFS, SeahorsePrefs))
#define SEAHORSE_PREFS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_PREFS, SeahorsePrefsClass))
#define SEAHORSE_IS_PREFS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_PREFS))
#define SEAHORSE_IS_PREFS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_PREFS))
#define SEAHORSE_PREFS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_PREFS, SeahorsePrefsClass))

typedef struct _SeahorsePrefs SeahorsePrefs;
typedef struct _SeahorsePrefsClass SeahorsePrefsClass;
typedef struct _SeahorsePrefsPrivate SeahorsePrefsPrivate;

#define SEAHORSE_TYPE_REGISTRY (seahorse_registry_get_type ())
#define SEAHORSE_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_REGISTRY, SeahorseRegistry))
#define SEAHORSE_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_REGISTRY, SeahorseRegistryClass))
#define SEAHORSE_IS_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_REGISTRY))
#define SEAHORSE_IS_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_REGISTRY))
#define SEAHORSE_REGISTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_REGISTRY, SeahorseRegistryClass))

typedef struct _SeahorseRegistry SeahorseRegistry;
typedef struct _SeahorseRegistryClass SeahorseRegistryClass;
typedef struct _SeahorseRegistryPrivate SeahorseRegistryPrivate;

#define SEAHORSE_TYPE_SERVER_CATEGORY (seahorse_server_category_get_type ())
#define SEAHORSE_SERVER_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_SERVER_CATEGORY, SeahorseServerCategory))
#define SEAHORSE_SERVER_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_SERVER_CATEGORY, SeahorseServerCategoryClass))
#define SEAHORSE_IS_SERVER_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_SERVER_CATEGORY))
#define SEAHORSE_IS_SERVER_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_SERVER_CATEGORY))
#define SEAHORSE_SERVER_CATEGORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_SERVER_CATEGORY, SeahorseServerCategoryClass))

typedef struct _SeahorseServerCategory SeahorseServerCategory;
typedef struct _SeahorseServerCategoryClass SeahorseServerCategoryClass;
typedef struct _SeahorseServerCategoryPrivate SeahorseServerCategoryPrivate;
typedef gboolean (*SeahorseValidUriFunc) (const gchar* uri);
typedef enum  {
	SEAHORSE_VALIDITY_REVOKED = -3,
	SEAHORSE_VALIDITY_DISABLED = -2,
	SEAHORSE_VALIDITY_NEVER = -1,
	SEAHORSE_VALIDITY_UNKNOWN = 0,
	SEAHORSE_VALIDITY_MARGINAL = 1,
	SEAHORSE_VALIDITY_FULL = 5,
	SEAHORSE_VALIDITY_ULTIMATE = 10
} SeahorseValidity;

#define SEAHORSE_TYPE_VALIDITY (seahorse_validity_get_type ())

#define SEAHORSE_TYPE_VIEWABLE (seahorse_viewable_get_type ())
#define SEAHORSE_VIEWABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_VIEWABLE, SeahorseViewable))
#define SEAHORSE_IS_VIEWABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_VIEWABLE))
#define SEAHORSE_VIEWABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SEAHORSE_TYPE_VIEWABLE, SeahorseViewableIface))

typedef struct _SeahorseViewable SeahorseViewable;
typedef struct _SeahorseViewableIface SeahorseViewableIface;

#define SEAHORSE_TYPE_KEYSERVER_CONTROL (seahorse_keyserver_control_get_type ())
#define SEAHORSE_KEYSERVER_CONTROL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_KEYSERVER_CONTROL, SeahorseKeyserverControl))
#define SEAHORSE_KEYSERVER_CONTROL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_KEYSERVER_CONTROL, SeahorseKeyserverControlClass))
#define SEAHORSE_IS_KEYSERVER_CONTROL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_KEYSERVER_CONTROL))
#define SEAHORSE_IS_KEYSERVER_CONTROL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_KEYSERVER_CONTROL))
#define SEAHORSE_KEYSERVER_CONTROL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_KEYSERVER_CONTROL, SeahorseKeyserverControlClass))

typedef struct _SeahorseKeyserverControl SeahorseKeyserverControl;
typedef struct _SeahorseKeyserverControlClass SeahorseKeyserverControlClass;
typedef struct _SeahorseKeyserverControlPrivate SeahorseKeyserverControlPrivate;

#define SEAHORSE_TYPE_PREFS_KEYSERVERS (seahorse_prefs_keyservers_get_type ())
#define SEAHORSE_PREFS_KEYSERVERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_PREFS_KEYSERVERS, SeahorsePrefsKeyservers))
#define SEAHORSE_PREFS_KEYSERVERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_PREFS_KEYSERVERS, SeahorsePrefsKeyserversClass))
#define SEAHORSE_IS_PREFS_KEYSERVERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_PREFS_KEYSERVERS))
#define SEAHORSE_IS_PREFS_KEYSERVERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_PREFS_KEYSERVERS))
#define SEAHORSE_PREFS_KEYSERVERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_PREFS_KEYSERVERS, SeahorsePrefsKeyserversClass))

typedef struct _SeahorsePrefsKeyservers SeahorsePrefsKeyservers;
typedef struct _SeahorsePrefsKeyserversClass SeahorsePrefsKeyserversClass;
typedef struct _SeahorsePrefsKeyserversPrivate SeahorsePrefsKeyserversPrivate;

struct _SeahorseActionGroup {
	GSimpleActionGroup parent_instance;
	SeahorseActionGroupPrivate * priv;
};

struct _SeahorseActionGroupClass {
	GSimpleActionGroupClass parent_class;
	void (*set_actions_for_selected_objects) (SeahorseActionGroup* self, GList* objects);
};

struct _SeahorseAddKeyserverDialog {
	GtkDialog parent_instance;
	SeahorseAddKeyserverDialogPrivate * priv;
};

struct _SeahorseAddKeyserverDialogClass {
	GtkDialogClass parent_class;
};

struct _SeahorseAppSettings {
	GSettings parent_instance;
	SeahorseAppSettingsPrivate * priv;
};

struct _SeahorseAppSettingsClass {
	GSettingsClass parent_class;
};

struct _SeahorsePlaceIface {
	GTypeInterface parent_iface;
	void (*load) (SeahorsePlace* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*load_finish) (SeahorsePlace* self, GAsyncResult* _res_, GError** error);
	gchar* (*get_label) (SeahorsePlace* self);
	void (*set_label) (SeahorsePlace* self, const gchar* value);
	gchar* (*get_description) (SeahorsePlace* self);
	gchar* (*get_uri) (SeahorsePlace* self);
	GIcon* (*get_icon) (SeahorsePlace* self);
	SeahorsePlaceCategory (*get_category) (SeahorsePlace* self);
	gboolean (*get_show_if_empty) (SeahorsePlace* self);
	GActionGroup* (*get_actions) (SeahorsePlace* self);
	const gchar* (*get_action_prefix) (SeahorsePlace* self);
	GMenuModel* (*get_menu_model) (SeahorsePlace* self);
};

struct _SeahorseBackendIface {
	GTypeInterface parent_iface;
	SeahorsePlace* (*lookup_place) (SeahorseBackend* self, const gchar* uri);
	const gchar* (*get_name) (SeahorseBackend* self);
	const gchar* (*get_label) (SeahorseBackend* self);
	const gchar* (*get_description) (SeahorseBackend* self);
	SeahorseActionGroup* (*get_actions) (SeahorseBackend* self);
	gboolean (*get_loaded) (SeahorseBackend* self);
};

struct _SeahorseCatalog {
	GtkApplicationWindow parent_instance;
	SeahorseCatalogPrivate * priv;
	GMenuModel* context_menu;
};

struct _SeahorseCatalogClass {
	GtkApplicationWindowClass parent_class;
	GList* (*get_backends) (SeahorseCatalog* self);
	GList* (*get_selected_objects) (SeahorseCatalog* self);
	void (*selection_changed) (SeahorseCatalog* self);
};

struct _SeahorseDatePicker {
	GtkBox parent_instance;
	SeahorseDatePickerPrivate * priv;
};

struct _SeahorseDatePickerClass {
	GtkBoxClass parent_class;
};

struct _SeahorseDeletableIface {
	GTypeInterface parent_iface;
	SeahorseDeleter* (*create_deleter) (SeahorseDeletable* self);
	gboolean (*get_deletable) (SeahorseDeletable* self);
};

struct _SeahorseDeleteDialog {
	GtkMessageDialog parent_instance;
	SeahorseDeleteDialogPrivate * priv;
};

struct _SeahorseDeleteDialogClass {
	GtkMessageDialogClass parent_class;
};

struct _SeahorseDeleter {
	GObject parent_instance;
	SeahorseDeleterPrivate * priv;
};

struct _SeahorseDeleterClass {
	GObjectClass parent_class;
	GtkDialog* (*create_confirm) (SeahorseDeleter* self, GtkWindow* parent);
	GList* (*get_objects) (SeahorseDeleter* self);
	gboolean (*add_object) (SeahorseDeleter* self, GObject* obj);
	void (*delete) (SeahorseDeleter* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*delete_finish) (SeahorseDeleter* self, GAsyncResult* _res_, GError** error);
};

struct _SeahorseExporterIface {
	GTypeInterface parent_iface;
	GList* (*get_objects) (SeahorseExporter* self);
	gboolean (*add_object) (SeahorseExporter* self, GObject* obj);
	void (*export) (SeahorseExporter* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	guint8* (*export_finish) (SeahorseExporter* self, GAsyncResult* _res_, size_t* result_length1, GError** error);
	gchar* (*get_filename) (SeahorseExporter* self);
	const gchar* (*get_content_type) (SeahorseExporter* self);
	GtkFileFilter* (*get_file_filter) (SeahorseExporter* self);
};

struct _SeahorseExportableIface {
	GTypeInterface parent_iface;
	GList* (*create_exporters) (SeahorseExportable* self, SeahorseExporterType type);
	gboolean (*get_exportable) (SeahorseExportable* self);
};

struct _SeahorseInteraction {
	GTlsInteraction parent_instance;
	SeahorseInteractionPrivate * priv;
};

struct _SeahorseInteractionClass {
	GTlsInteractionClass parent_class;
};

struct _SeahorseItemList {
	GObject parent_instance;
	SeahorseItemListPrivate * priv;
};

struct _SeahorseItemListClass {
	GObjectClass parent_class;
};

struct _SeahorseLockableIface {
	GTypeInterface parent_iface;
	void (*lock) (SeahorseLockable* self, GTlsInteraction* interaction, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*lock_finish) (SeahorseLockable* self, GAsyncResult* _res_, GError** error);
	void (*unlock) (SeahorseLockable* self, GTlsInteraction* interaction, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*unlock_finish) (SeahorseLockable* self, GAsyncResult* _res_, GError** error);
	gboolean (*get_lockable) (SeahorseLockable* self);
	gboolean (*get_unlockable) (SeahorseLockable* self);
};

struct _SeahorseObject {
	GObject parent_instance;
	SeahorseObjectPrivate * priv;
};

struct _SeahorseObjectClass {
	GObjectClass parent_class;
};

struct _SeahorsePassphrasePrompt {
	GtkDialog parent_instance;
	SeahorsePassphrasePromptPrivate * priv;
};

struct _SeahorsePassphrasePromptClass {
	GtkDialogClass parent_class;
};

struct _SeahorsePgpSettings {
	GSettings parent_instance;
	SeahorsePgpSettingsPrivate * priv;
};

struct _SeahorsePgpSettingsClass {
	GSettingsClass parent_class;
};

struct _SeahorsePrefs {
	HdyPreferencesWindow parent_instance;
	SeahorsePrefsPrivate * priv;
};

struct _SeahorsePrefsClass {
	HdyPreferencesWindowClass parent_class;
};

struct _SeahorseRegistry {
	GObject parent_instance;
	SeahorseRegistryPrivate * priv;
};

struct _SeahorseRegistryClass {
	GObjectClass parent_class;
};

struct _SeahorseServerCategory {
	GObject parent_instance;
	SeahorseServerCategoryPrivate * priv;
	SeahorseValidUriFunc validator;
};

struct _SeahorseServerCategoryClass {
	GObjectClass parent_class;
};

struct _SeahorseViewableIface {
	GTypeInterface parent_iface;
	GtkWindow* (*create_viewer) (SeahorseViewable* self, GtkWindow* parent);
};

struct _SeahorseKeyserverControl {
	GtkComboBox parent_instance;
	SeahorseKeyserverControlPrivate * priv;
};

struct _SeahorseKeyserverControlClass {
	GtkComboBoxClass parent_class;
};

struct _SeahorsePrefsKeyservers {
	HdyPreferencesPage parent_instance;
	SeahorsePrefsKeyserversPrivate * priv;
	GtkGrid* keyserver_tab;
};

struct _SeahorsePrefsKeyserversClass {
	HdyPreferencesPageClass parent_class;
};

VALA_EXTERN GType seahorse_action_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseActionGroup, g_object_unref)
VALA_EXTERN void seahorse_action_group_set_actions_for_selected_objects (SeahorseActionGroup* self,
                                                             GList* objects);
VALA_EXTERN SeahorseActionGroup* seahorse_action_group_new (void);
VALA_EXTERN SeahorseActionGroup* seahorse_action_group_construct (GType object_type);
VALA_EXTERN const gchar* seahorse_action_group_get_prefix (SeahorseActionGroup* self);
VALA_EXTERN void seahorse_action_group_set_prefix (SeahorseActionGroup* self,
                                       const gchar* value);
VALA_EXTERN GType seahorse_catalog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseCatalog, g_object_unref)
VALA_EXTERN SeahorseCatalog* seahorse_action_group_get_catalog (SeahorseActionGroup* self);
VALA_EXTERN void seahorse_action_group_set_catalog (SeahorseActionGroup* self,
                                        SeahorseCatalog* value);
VALA_EXTERN GType seahorse_add_keyserver_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseAddKeyserverDialog, g_object_unref)
VALA_EXTERN SeahorseAddKeyserverDialog* seahorse_add_keyserver_dialog_new (GtkWindow* parent);
VALA_EXTERN SeahorseAddKeyserverDialog* seahorse_add_keyserver_dialog_construct (GType object_type,
                                                                     GtkWindow* parent);
VALA_EXTERN gchar* seahorse_add_keyserver_dialog_calculate_keyserver_uri (SeahorseAddKeyserverDialog* self);
VALA_EXTERN GType seahorse_app_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseAppSettings, g_object_unref)
VALA_EXTERN SeahorseAppSettings* seahorse_app_settings_new (void);
VALA_EXTERN SeahorseAppSettings* seahorse_app_settings_construct (GType object_type);
VALA_EXTERN SeahorseAppSettings* seahorse_app_settings_instance (void);
VALA_EXTERN gchar** seahorse_app_settings_get_last_search_servers (SeahorseAppSettings* self);
VALA_EXTERN void seahorse_app_settings_set_last_search_servers (SeahorseAppSettings* self,
                                                    gchar** value);
VALA_EXTERN gchar* seahorse_app_settings_get_last_search_text (SeahorseAppSettings* self);
VALA_EXTERN void seahorse_app_settings_set_last_search_text (SeahorseAppSettings* self,
                                                 const gchar* value);
VALA_EXTERN gboolean seahorse_app_settings_get_server_auto_publish (SeahorseAppSettings* self);
VALA_EXTERN void seahorse_app_settings_set_server_auto_publish (SeahorseAppSettings* self,
                                                    gboolean value);
VALA_EXTERN gboolean seahorse_app_settings_get_server_auto_retrieve (SeahorseAppSettings* self);
VALA_EXTERN void seahorse_app_settings_set_server_auto_retrieve (SeahorseAppSettings* self,
                                                     gboolean value);
VALA_EXTERN gchar* seahorse_app_settings_get_server_publish_to (SeahorseAppSettings* self);
VALA_EXTERN void seahorse_app_settings_set_server_publish_to (SeahorseAppSettings* self,
                                                  const gchar* value);
VALA_EXTERN GType seahorse_place_category_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType seahorse_place_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType seahorse_backend_get_type (void) G_GNUC_CONST ;
VALA_EXTERN SeahorsePlace* seahorse_backend_lookup_place (SeahorseBackend* self,
                                              const gchar* uri);
VALA_EXTERN void seahorse_backend_register (SeahorseBackend* self);
VALA_EXTERN GList* seahorse_backend_get_registered (void);
VALA_EXTERN const gchar* seahorse_backend_get_name (SeahorseBackend* self);
VALA_EXTERN const gchar* seahorse_backend_get_label (SeahorseBackend* self);
VALA_EXTERN const gchar* seahorse_backend_get_description (SeahorseBackend* self);
VALA_EXTERN SeahorseActionGroup* seahorse_backend_get_actions (SeahorseBackend* self);
VALA_EXTERN gboolean seahorse_backend_get_loaded (SeahorseBackend* self);
VALA_EXTERN GList* seahorse_catalog_get_backends (SeahorseCatalog* self);
VALA_EXTERN GList* seahorse_catalog_get_selected_objects (SeahorseCatalog* self);
VALA_EXTERN void seahorse_catalog_show_properties (SeahorseCatalog* self,
                                       GObject* obj);
VALA_EXTERN void seahorse_catalog_show_context_menu (SeahorseCatalog* self,
                                         GdkEvent* event);
VALA_EXTERN SeahorseCatalog* seahorse_catalog_construct (GType object_type);
VALA_EXTERN const gchar* seahorse_catalog_get_ui_name (SeahorseCatalog* self);
VALA_EXTERN GType seahorse_date_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseDatePicker, g_object_unref)
VALA_EXTERN GtkWidget* seahorse_date_picker_new (void);
VALA_EXTERN GtkWidget* seahorse_date_picker_construct (GType object_type);
VALA_EXTERN GDateTime* seahorse_date_picker_get_datetime (SeahorseDatePicker* self);
VALA_EXTERN void seahorse_date_picker_set_datetime (SeahorseDatePicker* self,
                                        GDateTime* value);
VALA_EXTERN GType seahorse_deleter_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseDeleter, g_object_unref)
VALA_EXTERN GType seahorse_deletable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseDeletable, g_object_unref)
VALA_EXTERN SeahorseDeleter* seahorse_deletable_create_deleter (SeahorseDeletable* self);
VALA_EXTERN gboolean seahorse_deletable_can_delete (GObject* obj);
VALA_EXTERN gint seahorse_deletable_delete_with_prompt_wait (GList* objects,
                                                 GtkWindow* parent,
                                                 GError** error);
VALA_EXTERN gboolean seahorse_deletable_get_deletable (SeahorseDeletable* self);
VALA_EXTERN GType seahorse_delete_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseDeleteDialog, g_object_unref)
VALA_EXTERN GtkDialog* seahorse_delete_dialog_new (GtkWindow* parent,
                                       const gchar* format,
                                       ...);
VALA_EXTERN GtkDialog* seahorse_delete_dialog_construct (GType object_type,
                                             GtkWindow* parent,
                                             const gchar* format,
                                             ...);
VALA_EXTERN GtkDialog* seahorse_delete_dialog_constructv (GType object_type,
                                              GtkWindow* parent,
                                              const gchar* format,
                                              va_list _vala_va_list);
VALA_EXTERN gboolean seahorse_delete_dialog_prompt (GtkWindow* parent,
                                        const gchar* text);
VALA_EXTERN const gchar* seahorse_delete_dialog_get_check_label (SeahorseDeleteDialog* self);
VALA_EXTERN void seahorse_delete_dialog_set_check_label (SeahorseDeleteDialog* self,
                                             const gchar* value);
VALA_EXTERN gboolean seahorse_delete_dialog_get_check_value (SeahorseDeleteDialog* self);
VALA_EXTERN void seahorse_delete_dialog_set_check_value (SeahorseDeleteDialog* self,
                                             gboolean value);
VALA_EXTERN gboolean seahorse_delete_dialog_get_check_require (SeahorseDeleteDialog* self);
VALA_EXTERN void seahorse_delete_dialog_set_check_require (SeahorseDeleteDialog* self,
                                               gboolean value);
VALA_EXTERN GtkDialog* seahorse_deleter_create_confirm (SeahorseDeleter* self,
                                            GtkWindow* parent);
VALA_EXTERN GList* seahorse_deleter_get_objects (SeahorseDeleter* self);
VALA_EXTERN gboolean seahorse_deleter_add_object (SeahorseDeleter* self,
                                      GObject* obj);
VALA_EXTERN void seahorse_deleter_delete (SeahorseDeleter* self,
                              GCancellable* cancellable,
                              GAsyncReadyCallback _callback_,
                              gpointer _user_data_);
VALA_EXTERN gboolean seahorse_deleter_delete_finish (SeahorseDeleter* self,
                                         GAsyncResult* _res_,
                                         GError** error);
VALA_EXTERN gboolean seahorse_deleter_prompt (SeahorseDeleter* self,
                                  GtkWindow* parent);
VALA_EXTERN SeahorseDeleter* seahorse_deleter_construct (GType object_type);
VALA_EXTERN GType seahorse_exporter_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType seahorse_exporter_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseExporter, g_object_unref)
VALA_EXTERN GType seahorse_exportable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseExportable, g_object_unref)
VALA_EXTERN GList* seahorse_exportable_create_exporters (SeahorseExportable* self,
                                             SeahorseExporterType type);
VALA_EXTERN gboolean seahorse_exportable_can_export (GObject* object);
VALA_EXTERN gint seahorse_exportable_export_to_directory_wait (GList* objects,
                                                   const gchar* directory,
                                                   GError** error);
VALA_EXTERN guint seahorse_exportable_export_to_text_wait (GList* objects,
                                               guint8** output,
                                               size_t* output_length1,
                                               GError** error);
VALA_EXTERN gint seahorse_exportable_export_to_prompt_wait (GList* objects,
                                                GtkWindow* parent,
                                                GError** error);
VALA_EXTERN gboolean seahorse_exportable_prompt (GList* exporters,
                                     GtkWindow* parent,
                                     gchar** directory,
                                     GFile** chosen_file,
                                     SeahorseExporter** chosen_exporter);
VALA_EXTERN gboolean seahorse_exportable_get_exportable (SeahorseExportable* self);
VALA_EXTERN GList* seahorse_exporter_get_objects (SeahorseExporter* self);
VALA_EXTERN gboolean seahorse_exporter_add_object (SeahorseExporter* self,
                                       GObject* obj);
VALA_EXTERN void seahorse_exporter_export (SeahorseExporter* self,
                               GCancellable* cancellable,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_);
VALA_EXTERN guint8* seahorse_exporter_export_finish (SeahorseExporter* self,
                                         GAsyncResult* _res_,
                                         size_t* result_length1,
                                         GError** error);
VALA_EXTERN void seahorse_exporter_export_to_file (SeahorseExporter* self,
                                       GFile* file,
                                       gboolean overwrite,
                                       GCancellable* cancellable,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
VALA_EXTERN gboolean seahorse_exporter_export_to_file_finish (SeahorseExporter* self,
                                                  GAsyncResult* _res_,
                                                  GError** error);
VALA_EXTERN gchar* seahorse_exporter_get_filename (SeahorseExporter* self);
VALA_EXTERN const gchar* seahorse_exporter_get_content_type (SeahorseExporter* self);
VALA_EXTERN GtkFileFilter* seahorse_exporter_get_file_filter (SeahorseExporter* self);
VALA_EXTERN gboolean seahorse__icons_inited;
VALA_EXTERN void seahorse_icons_init (void);
VALA_EXTERN GType seahorse_interaction_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseInteraction, g_object_unref)
VALA_EXTERN SeahorseInteraction* seahorse_interaction_new (GtkWindow* parent);
VALA_EXTERN SeahorseInteraction* seahorse_interaction_construct (GType object_type,
                                                     GtkWindow* parent);
VALA_EXTERN GtkWindow* seahorse_interaction_get_parent (SeahorseInteraction* self);
VALA_EXTERN void seahorse_interaction_set_parent (SeahorseInteraction* self,
                                      GtkWindow* value);
VALA_EXTERN GType seahorse_item_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseItemList, g_object_unref)
VALA_EXTERN GType seahorse_item_list_show_filter_get_type (void) G_GNUC_CONST ;
VALA_EXTERN const gchar* seahorse_item_list_show_filter_to_string (SeahorseItemListShowFilter self);
VALA_EXTERN SeahorseItemListShowFilter seahorse_item_list_show_filter_from_string (const gchar* str);
VALA_EXTERN SeahorseItemList* seahorse_item_list_new (GcrCollection* collection);
VALA_EXTERN SeahorseItemList* seahorse_item_list_construct (GType object_type,
                                                GcrCollection* collection);
VALA_EXTERN void seahorse_item_list_refilter (SeahorseItemList* self);
VALA_EXTERN GcrCollection* seahorse_item_list_get_base_collection (SeahorseItemList* self);
VALA_EXTERN SeahorseItemListShowFilter seahorse_item_list_get_showfilter (SeahorseItemList* self);
VALA_EXTERN void seahorse_item_list_set_showfilter (SeahorseItemList* self,
                                        SeahorseItemListShowFilter value);
VALA_EXTERN void seahorse_item_list_set_filter_text (SeahorseItemList* self,
                                         const gchar* value);
VALA_EXTERN GType seahorse_lockable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseLockable, g_object_unref)
VALA_EXTERN void seahorse_lockable_lock (SeahorseLockable* self,
                             GTlsInteraction* interaction,
                             GCancellable* cancellable,
                             GAsyncReadyCallback _callback_,
                             gpointer _user_data_);
VALA_EXTERN gboolean seahorse_lockable_lock_finish (SeahorseLockable* self,
                                        GAsyncResult* _res_,
                                        GError** error);
VALA_EXTERN void seahorse_lockable_unlock (SeahorseLockable* self,
                               GTlsInteraction* interaction,
                               GCancellable* cancellable,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_);
VALA_EXTERN gboolean seahorse_lockable_unlock_finish (SeahorseLockable* self,
                                          GAsyncResult* _res_,
                                          GError** error);
VALA_EXTERN gboolean seahorse_lockable_can_lock (GObject* object);
VALA_EXTERN gboolean seahorse_lockable_can_unlock (GObject* object);
VALA_EXTERN gboolean seahorse_lockable_get_lockable (SeahorseLockable* self);
VALA_EXTERN gboolean seahorse_lockable_get_unlockable (SeahorseLockable* self);
VALA_EXTERN GType seahorse_object_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseObject, g_object_unref)
VALA_EXTERN SeahorseObject* seahorse_object_new (void);
VALA_EXTERN SeahorseObject* seahorse_object_construct (GType object_type);
VALA_EXTERN GType seahorse_flags_get_type (void) G_GNUC_CONST ;
VALA_EXTERN SeahorseFlags seahorse_object_get_flags (SeahorseObject* self);
VALA_EXTERN void seahorse_object_set_flags (SeahorseObject* self,
                                SeahorseFlags flags);
VALA_EXTERN SeahorsePlace* seahorse_object_get_place (SeahorseObject* self);
VALA_EXTERN void seahorse_object_set_place (SeahorseObject* self,
                                SeahorsePlace* value);
VALA_EXTERN GIcon* seahorse_object_get_icon (SeahorseObject* self);
VALA_EXTERN void seahorse_object_set_icon (SeahorseObject* self,
                               GIcon* value);
VALA_EXTERN const gchar* seahorse_object_get_label (SeahorseObject* self);
VALA_EXTERN void seahorse_object_set_label (SeahorseObject* self,
                                const gchar* value);
VALA_EXTERN const gchar* seahorse_object_get_markup (SeahorseObject* self);
VALA_EXTERN void seahorse_object_set_markup (SeahorseObject* self,
                                 const gchar* value);
VALA_EXTERN const gchar* seahorse_object_get_nickname (SeahorseObject* self);
VALA_EXTERN void seahorse_object_set_nickname (SeahorseObject* self,
                                   const gchar* value);
VALA_EXTERN const gchar* seahorse_object_get_identifier (SeahorseObject* self);
VALA_EXTERN void seahorse_object_set_identifier (SeahorseObject* self,
                                     const gchar* value);
VALA_EXTERN GType seahorse_usage_get_type (void) G_GNUC_CONST ;
VALA_EXTERN SeahorseUsage seahorse_object_get_usage (SeahorseObject* self);
VALA_EXTERN void seahorse_object_set_usage (SeahorseObject* self,
                                SeahorseUsage value);
VALA_EXTERN SeahorseFlags seahorse_object_get_object_flags (SeahorseObject* self);
VALA_EXTERN void seahorse_object_set_object_flags (SeahorseObject* self,
                                       SeahorseFlags value);
VALA_EXTERN gboolean seahorse_object_get_deletable (SeahorseObject* self);
VALA_EXTERN gboolean seahorse_object_get_exportable (SeahorseObject* self);
VALA_EXTERN GType seahorse_passphrase_prompt_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorsePassphrasePrompt, g_object_unref)
VALA_EXTERN SeahorsePassphrasePrompt* seahorse_passphrase_prompt_new (const gchar* title,
                                                          const gchar* description,
                                                          const gchar* prompt,
                                                          const gchar* check,
                                                          gboolean confirm);
VALA_EXTERN SeahorsePassphrasePrompt* seahorse_passphrase_prompt_construct (GType object_type,
                                                                const gchar* title,
                                                                const gchar* description,
                                                                const gchar* prompt,
                                                                const gchar* check,
                                                                gboolean confirm);
VALA_EXTERN SeahorsePassphrasePrompt* seahorse_passphrase_prompt_show_dialog (const gchar* title,
                                                                  const gchar* description,
                                                                  const gchar* prompt,
                                                                  const gchar* check,
                                                                  gboolean confirm);
VALA_EXTERN gchar* seahorse_passphrase_prompt_get_text (SeahorsePassphrasePrompt* self);
VALA_EXTERN gboolean seahorse_passphrase_prompt_checked (SeahorsePassphrasePrompt* self);
VALA_EXTERN GType seahorse_pgp_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorsePgpSettings, g_object_unref)
VALA_EXTERN SeahorsePgpSettings* seahorse_pgp_settings_new (void);
VALA_EXTERN SeahorsePgpSettings* seahorse_pgp_settings_construct (GType object_type);
VALA_EXTERN SeahorsePgpSettings* seahorse_pgp_settings_instance (void);
VALA_EXTERN gchar** seahorse_pgp_settings_get_uris (SeahorsePgpSettings* self);
VALA_EXTERN gchar** seahorse_pgp_settings_get_names (SeahorsePgpSettings* self);
VALA_EXTERN void seahorse_pgp_settings_add_keyserver (SeahorsePgpSettings* self,
                                          const gchar* uri,
                                          const gchar* name);
VALA_EXTERN void seahorse_pgp_settings_remove_keyserver (SeahorsePgpSettings* self,
                                             const gchar* uri);
VALA_EXTERN gboolean seahorse_pgp_settings_get_ascii_armor (SeahorsePgpSettings* self);
VALA_EXTERN void seahorse_pgp_settings_set_ascii_armor (SeahorsePgpSettings* self,
                                            gboolean value);
VALA_EXTERN gchar* seahorse_pgp_settings_get_default_key (SeahorsePgpSettings* self);
VALA_EXTERN void seahorse_pgp_settings_set_default_key (SeahorsePgpSettings* self,
                                            const gchar* value);
VALA_EXTERN gboolean seahorse_pgp_settings_get_encrypt_to_self (SeahorsePgpSettings* self);
VALA_EXTERN void seahorse_pgp_settings_set_encrypt_to_self (SeahorsePgpSettings* self,
                                                gboolean value);
VALA_EXTERN gchar** seahorse_pgp_settings_get_keyservers (SeahorsePgpSettings* self,
                                              gint* result_length1);
VALA_EXTERN void seahorse_pgp_settings_set_keyservers (SeahorsePgpSettings* self,
                                           gchar** value,
                                           gint value_length1);
VALA_EXTERN gchar* seahorse_pgp_settings_get_last_signer (SeahorsePgpSettings* self);
VALA_EXTERN void seahorse_pgp_settings_set_last_signer (SeahorsePgpSettings* self,
                                            const gchar* value);
VALA_EXTERN gchar* seahorse_pgp_settings_get_sort_recipients_by (SeahorsePgpSettings* self);
VALA_EXTERN void seahorse_pgp_settings_set_sort_recipients_by (SeahorsePgpSettings* self,
                                                   const gchar* value);
VALA_EXTERN const gchar* seahorse_place_category_to_string (SeahorsePlaceCategory self);
VALA_EXTERN void seahorse_place_load (SeahorsePlace* self,
                          GCancellable* cancellable,
                          GAsyncReadyCallback _callback_,
                          gpointer _user_data_);
VALA_EXTERN gboolean seahorse_place_load_finish (SeahorsePlace* self,
                                     GAsyncResult* _res_,
                                     GError** error);
VALA_EXTERN gchar* seahorse_place_get_label (SeahorsePlace* self);
VALA_EXTERN void seahorse_place_set_label (SeahorsePlace* self,
                               const gchar* value);
VALA_EXTERN gchar* seahorse_place_get_description (SeahorsePlace* self);
VALA_EXTERN gchar* seahorse_place_get_uri (SeahorsePlace* self);
VALA_EXTERN GIcon* seahorse_place_get_icon (SeahorsePlace* self);
VALA_EXTERN SeahorsePlaceCategory seahorse_place_get_category (SeahorsePlace* self);
VALA_EXTERN gboolean seahorse_place_get_show_if_empty (SeahorsePlace* self);
VALA_EXTERN GActionGroup* seahorse_place_get_actions (SeahorsePlace* self);
VALA_EXTERN const gchar* seahorse_place_get_action_prefix (SeahorsePlace* self);
VALA_EXTERN GMenuModel* seahorse_place_get_menu_model (SeahorsePlace* self);
VALA_EXTERN GType seahorse_prefs_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorsePrefs, g_object_unref)
VALA_EXTERN SeahorsePrefs* seahorse_prefs_new (GtkWindow* parent);
VALA_EXTERN SeahorsePrefs* seahorse_prefs_construct (GType object_type,
                                         GtkWindow* parent);
VALA_EXTERN gboolean seahorse_prefs_available (void);
VALA_EXTERN GType seahorse_registry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseRegistry, g_object_unref)
VALA_EXTERN void seahorse_registry_cleanup (void);
VALA_EXTERN void seahorse_registry_register_object (GObject* object,
                                        const gchar* category);
VALA_EXTERN GObject* seahorse_registry_object_instance (const gchar* category);
VALA_EXTERN GList* seahorse_registry_object_instances (const gchar* category);
VALA_EXTERN SeahorseRegistry* seahorse_registry_new (void);
VALA_EXTERN SeahorseRegistry* seahorse_registry_construct (GType object_type);
VALA_EXTERN GType seahorse_server_category_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseServerCategory, g_object_unref)
VALA_EXTERN SeahorseServerCategory* seahorse_server_category_new (GType gtype,
                                                      const gchar* scheme,
                                                      const gchar* description,
                                                      SeahorseValidUriFunc validator);
VALA_EXTERN SeahorseServerCategory* seahorse_server_category_construct (GType object_type,
                                                            GType gtype,
                                                            const gchar* scheme,
                                                            const gchar* description,
                                                            SeahorseValidUriFunc validator);
VALA_EXTERN SeahorseServerSource* seahorse_server_category_create_server (const gchar* uri);
VALA_EXTERN void seahorse_server_category_init (void);
VALA_EXTERN gchar** seahorse_server_category_get_types (void);
VALA_EXTERN SeahorseServerCategory* seahorse_server_category_find_category (const gchar* scheme);
VALA_EXTERN gboolean seahorse_server_category_is_valid_uri (const gchar* uri);
VALA_EXTERN GType seahorse_server_category_get_gtype (SeahorseServerCategory* self);
VALA_EXTERN const gchar* seahorse_server_category_get_scheme (SeahorseServerCategory* self);
VALA_EXTERN const gchar* seahorse_server_category_get_description (SeahorseServerCategory* self);
VALA_EXTERN void seahorse_util_show_error (GtkWidget* parent,
                               const gchar* heading,
                               const gchar* message);
VALA_EXTERN void seahorse_util_toggle_action (GSimpleAction* action,
                                  GVariant* variant,
                                  void* user_data);
VALA_EXTERN GType seahorse_validity_get_type (void) G_GNUC_CONST ;
VALA_EXTERN const gchar* seahorse_validity_get_string (SeahorseValidity self);
VALA_EXTERN GType seahorse_viewable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseViewable, g_object_unref)
VALA_EXTERN GtkWindow* seahorse_viewable_create_viewer (SeahorseViewable* self,
                                            GtkWindow* parent);
VALA_EXTERN gboolean seahorse_viewable_can_view (GObject* object);
VALA_EXTERN gboolean seahorse_viewable_view (GObject* object,
                                 GtkWindow* parent);
VALA_EXTERN GType seahorse_keyserver_control_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseKeyserverControl, g_object_unref)
VALA_EXTERN SeahorseKeyserverControl* seahorse_keyserver_control_new (const gchar* settings_key,
                                                          const gchar* none_option);
VALA_EXTERN SeahorseKeyserverControl* seahorse_keyserver_control_construct (GType object_type,
                                                                const gchar* settings_key,
                                                                const gchar* none_option);
VALA_EXTERN gchar* seahorse_keyserver_control_selected (SeahorseKeyserverControl* self);
VALA_EXTERN const gchar* seahorse_keyserver_control_get_settings_key (SeahorseKeyserverControl* self);
VALA_EXTERN void seahorse_keyserver_control_set_settings_key (SeahorseKeyserverControl* self,
                                                  const gchar* value);
VALA_EXTERN const gchar* seahorse_keyserver_control_get_none_option (SeahorseKeyserverControl* self);
VALA_EXTERN void seahorse_keyserver_control_set_none_option (SeahorseKeyserverControl* self,
                                                 const gchar* value);
VALA_EXTERN GType seahorse_prefs_keyservers_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorsePrefsKeyservers, g_object_unref)
VALA_EXTERN SeahorsePrefsKeyservers* seahorse_prefs_keyservers_new (void);
VALA_EXTERN SeahorsePrefsKeyservers* seahorse_prefs_keyservers_construct (GType object_type);

G_END_DECLS

#endif
