/* types.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from types.vala, do not modify */

/*
 * Seahorse
 *
 * Copyright (C) 2008 Stefan Walter
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

#include "seahorse-common.h"

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

 G_GNUC_NO_INLINE static GType
seahorse_usage_get_type_once (void)
{
	static const GEnumValue values[] = {{SEAHORSE_USAGE_NONE, "SEAHORSE_USAGE_NONE", "none"}, {SEAHORSE_USAGE_SYMMETRIC_KEY, "SEAHORSE_USAGE_SYMMETRIC_KEY", "symmetric-key"}, {SEAHORSE_USAGE_PUBLIC_KEY, "SEAHORSE_USAGE_PUBLIC_KEY", "public-key"}, {SEAHORSE_USAGE_PRIVATE_KEY, "SEAHORSE_USAGE_PRIVATE_KEY", "private-key"}, {SEAHORSE_USAGE_CREDENTIALS, "SEAHORSE_USAGE_CREDENTIALS", "credentials"}, {SEAHORSE_USAGE_IDENTITY, "SEAHORSE_USAGE_IDENTITY", "identity"}, {SEAHORSE_USAGE_OTHER, "SEAHORSE_USAGE_OTHER", "other"}, {0, NULL, NULL}};
	GType seahorse_usage_type_id;
	seahorse_usage_type_id = g_enum_register_static ("SeahorseUsage", values);
	return seahorse_usage_type_id;
}

GType
seahorse_usage_get_type (void)
{
	static volatile gsize seahorse_usage_type_id__once = 0;
	if (g_once_init_enter (&seahorse_usage_type_id__once)) {
		GType seahorse_usage_type_id;
		seahorse_usage_type_id = seahorse_usage_get_type_once ();
		g_once_init_leave (&seahorse_usage_type_id__once, seahorse_usage_type_id);
	}
	return seahorse_usage_type_id__once;
}

 G_GNUC_NO_INLINE static GType
seahorse_flags_get_type_once (void)
{
	static const GFlagsValue values[] = {{SEAHORSE_FLAG_NONE, "SEAHORSE_FLAG_NONE", "none"}, {SEAHORSE_FLAG_IS_VALID, "SEAHORSE_FLAG_IS_VALID", "is-valid"}, {SEAHORSE_FLAG_CAN_ENCRYPT, "SEAHORSE_FLAG_CAN_ENCRYPT", "can-encrypt"}, {SEAHORSE_FLAG_CAN_SIGN, "SEAHORSE_FLAG_CAN_SIGN", "can-sign"}, {SEAHORSE_FLAG_CAN_CERTIFY, "SEAHORSE_FLAG_CAN_CERTIFY", "can-certify"}, {SEAHORSE_FLAG_CAN_AUTHENTICATE, "SEAHORSE_FLAG_CAN_AUTHENTICATE", "can-authenticate"}, {SEAHORSE_FLAG_EXPIRED, "SEAHORSE_FLAG_EXPIRED", "expired"}, {SEAHORSE_FLAG_REVOKED, "SEAHORSE_FLAG_REVOKED", "revoked"}, {SEAHORSE_FLAG_DISABLED, "SEAHORSE_FLAG_DISABLED", "disabled"}, {SEAHORSE_FLAG_TRUSTED, "SEAHORSE_FLAG_TRUSTED", "trusted"}, {SEAHORSE_FLAG_PERSONAL, "SEAHORSE_FLAG_PERSONAL", "personal"}, {SEAHORSE_FLAG_EXPORTABLE, "SEAHORSE_FLAG_EXPORTABLE", "exportable"}, {SEAHORSE_FLAG_DELETABLE, "SEAHORSE_FLAG_DELETABLE", "deletable"}, {0, NULL, NULL}};
	GType seahorse_flags_type_id;
	seahorse_flags_type_id = g_flags_register_static ("SeahorseFlags", values);
	return seahorse_flags_type_id;
}

GType
seahorse_flags_get_type (void)
{
	static volatile gsize seahorse_flags_type_id__once = 0;
	if (g_once_init_enter (&seahorse_flags_type_id__once)) {
		GType seahorse_flags_type_id;
		seahorse_flags_type_id = seahorse_flags_get_type_once ();
		g_once_init_leave (&seahorse_flags_type_id__once, seahorse_flags_type_id);
	}
	return seahorse_flags_type_id__once;
}

