/* seahorse-gkr.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __GKR_SEAHORSE_GKR_H__
#define __GKR_SEAHORSE_GKR_H__

#include <glib-object.h>
#include <gcr/gcr-base.h>
#include "seahorse-common.h"
#include <glib.h>
#include <libsecret/secret.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gio/gio.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define SEAHORSE_GKR_NAME "gkr"

#define SEAHORSE_GKR_TYPE_BACKEND (seahorse_gkr_backend_get_type ())
#define SEAHORSE_GKR_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_BACKEND, SeahorseGkrBackend))
#define SEAHORSE_GKR_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_BACKEND, SeahorseGkrBackendClass))
#define SEAHORSE_GKR_IS_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_BACKEND))
#define SEAHORSE_GKR_IS_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_BACKEND))
#define SEAHORSE_GKR_BACKEND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_BACKEND, SeahorseGkrBackendClass))

typedef struct _SeahorseGkrBackend SeahorseGkrBackend;
typedef struct _SeahorseGkrBackendClass SeahorseGkrBackendClass;
typedef struct _SeahorseGkrBackendPrivate SeahorseGkrBackendPrivate;

#define SEAHORSE_GKR_TYPE_KEYRING (seahorse_gkr_keyring_get_type ())
#define SEAHORSE_GKR_KEYRING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_KEYRING, SeahorseGkrKeyring))
#define SEAHORSE_GKR_KEYRING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_KEYRING, SeahorseGkrKeyringClass))
#define SEAHORSE_GKR_IS_KEYRING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_KEYRING))
#define SEAHORSE_GKR_IS_KEYRING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_KEYRING))
#define SEAHORSE_GKR_KEYRING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_KEYRING, SeahorseGkrKeyringClass))

typedef struct _SeahorseGkrKeyring SeahorseGkrKeyring;
typedef struct _SeahorseGkrKeyringClass SeahorseGkrKeyringClass;

#define SEAHORSE_GKR_TYPE_BACKEND_ACTIONS (seahorse_gkr_backend_actions_get_type ())
#define SEAHORSE_GKR_BACKEND_ACTIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_BACKEND_ACTIONS, SeahorseGkrBackendActions))
#define SEAHORSE_GKR_BACKEND_ACTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_BACKEND_ACTIONS, SeahorseGkrBackendActionsClass))
#define SEAHORSE_GKR_IS_BACKEND_ACTIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_BACKEND_ACTIONS))
#define SEAHORSE_GKR_IS_BACKEND_ACTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_BACKEND_ACTIONS))
#define SEAHORSE_GKR_BACKEND_ACTIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_BACKEND_ACTIONS, SeahorseGkrBackendActionsClass))

typedef struct _SeahorseGkrBackendActions SeahorseGkrBackendActions;
typedef struct _SeahorseGkrBackendActionsClass SeahorseGkrBackendActionsClass;
typedef struct _SeahorseGkrBackendActionsPrivate SeahorseGkrBackendActionsPrivate;

#define SEAHORSE_GKR_TYPE_DIALOG (seahorse_gkr_dialog_get_type ())
#define SEAHORSE_GKR_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_DIALOG, SeahorseGkrDialog))
#define SEAHORSE_GKR_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_DIALOG, SeahorseGkrDialogClass))
#define SEAHORSE_GKR_IS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_DIALOG))
#define SEAHORSE_GKR_IS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_DIALOG))
#define SEAHORSE_GKR_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_DIALOG, SeahorseGkrDialogClass))

typedef struct _SeahorseGkrDialog SeahorseGkrDialog;
typedef struct _SeahorseGkrDialogClass SeahorseGkrDialogClass;
typedef struct _SeahorseGkrDialogPrivate SeahorseGkrDialogPrivate;

#define SEAHORSE_GKR_TYPE_ITEM_ADD (seahorse_gkr_item_add_get_type ())
#define SEAHORSE_GKR_ITEM_ADD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_ITEM_ADD, SeahorseGkrItemAdd))
#define SEAHORSE_GKR_ITEM_ADD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_ITEM_ADD, SeahorseGkrItemAddClass))
#define SEAHORSE_GKR_IS_ITEM_ADD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_ITEM_ADD))
#define SEAHORSE_GKR_IS_ITEM_ADD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_ITEM_ADD))
#define SEAHORSE_GKR_ITEM_ADD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_ITEM_ADD, SeahorseGkrItemAddClass))

typedef struct _SeahorseGkrItemAdd SeahorseGkrItemAdd;
typedef struct _SeahorseGkrItemAddClass SeahorseGkrItemAddClass;
typedef struct _SeahorseGkrItemAddPrivate SeahorseGkrItemAddPrivate;

#define SEAHORSE_GKR_TYPE_ITEM_INFO (seahorse_gkr_item_info_get_type ())
#define SEAHORSE_GKR_ITEM_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_ITEM_INFO, SeahorseGkrItemInfo))
#define SEAHORSE_GKR_ITEM_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_ITEM_INFO, SeahorseGkrItemInfoClass))
#define SEAHORSE_GKR_IS_ITEM_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_ITEM_INFO))
#define SEAHORSE_GKR_IS_ITEM_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_ITEM_INFO))
#define SEAHORSE_GKR_ITEM_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_ITEM_INFO, SeahorseGkrItemInfoClass))

typedef struct _SeahorseGkrItemInfo SeahorseGkrItemInfo;
typedef struct _SeahorseGkrItemInfoClass SeahorseGkrItemInfoClass;
typedef struct _SeahorseGkrItemInfoPrivate SeahorseGkrItemInfoPrivate;

#define SEAHORSE_GKR_TYPE_NM_CONNECTION_INFO (seahorse_gkr_nm_connection_info_get_type ())
#define SEAHORSE_GKR_NM_CONNECTION_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_NM_CONNECTION_INFO, SeahorseGkrNmConnectionInfo))
#define SEAHORSE_GKR_NM_CONNECTION_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_NM_CONNECTION_INFO, SeahorseGkrNmConnectionInfoClass))
#define SEAHORSE_GKR_IS_NM_CONNECTION_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_NM_CONNECTION_INFO))
#define SEAHORSE_GKR_IS_NM_CONNECTION_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_NM_CONNECTION_INFO))
#define SEAHORSE_GKR_NM_CONNECTION_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_NM_CONNECTION_INFO, SeahorseGkrNmConnectionInfoClass))

typedef struct _SeahorseGkrNmConnectionInfo SeahorseGkrNmConnectionInfo;
typedef struct _SeahorseGkrNmConnectionInfoClass SeahorseGkrNmConnectionInfoClass;
typedef struct _SeahorseGkrNmConnectionInfoPrivate SeahorseGkrNmConnectionInfoPrivate;

#define SEAHORSE_GKR_TYPE_GKR_NETWORK_PASS_INFO (seahorse_gkr_gkr_network_pass_info_get_type ())
#define SEAHORSE_GKR_GKR_NETWORK_PASS_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_GKR_NETWORK_PASS_INFO, SeahorseGkrGkrNetworkPassInfo))
#define SEAHORSE_GKR_GKR_NETWORK_PASS_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_GKR_NETWORK_PASS_INFO, SeahorseGkrGkrNetworkPassInfoClass))
#define SEAHORSE_GKR_IS_GKR_NETWORK_PASS_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_GKR_NETWORK_PASS_INFO))
#define SEAHORSE_GKR_IS_GKR_NETWORK_PASS_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_GKR_NETWORK_PASS_INFO))
#define SEAHORSE_GKR_GKR_NETWORK_PASS_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_GKR_NETWORK_PASS_INFO, SeahorseGkrGkrNetworkPassInfoClass))

typedef struct _SeahorseGkrGkrNetworkPassInfo SeahorseGkrGkrNetworkPassInfo;
typedef struct _SeahorseGkrGkrNetworkPassInfoClass SeahorseGkrGkrNetworkPassInfoClass;
typedef struct _SeahorseGkrGkrNetworkPassInfoPrivate SeahorseGkrGkrNetworkPassInfoPrivate;

#define SEAHORSE_GKR_TYPE_EDS_PASS_INFO (seahorse_gkr_eds_pass_info_get_type ())
#define SEAHORSE_GKR_EDS_PASS_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_EDS_PASS_INFO, SeahorseGkrEdsPassInfo))
#define SEAHORSE_GKR_EDS_PASS_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_EDS_PASS_INFO, SeahorseGkrEdsPassInfoClass))
#define SEAHORSE_GKR_IS_EDS_PASS_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_EDS_PASS_INFO))
#define SEAHORSE_GKR_IS_EDS_PASS_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_EDS_PASS_INFO))
#define SEAHORSE_GKR_EDS_PASS_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_EDS_PASS_INFO, SeahorseGkrEdsPassInfoClass))

typedef struct _SeahorseGkrEdsPassInfo SeahorseGkrEdsPassInfo;
typedef struct _SeahorseGkrEdsPassInfoClass SeahorseGkrEdsPassInfoClass;
typedef struct _SeahorseGkrEdsPassInfoPrivate SeahorseGkrEdsPassInfoPrivate;

#define SEAHORSE_GKR_TYPE_EPIPHANY_PASS_INFO (seahorse_gkr_epiphany_pass_info_get_type ())
#define SEAHORSE_GKR_EPIPHANY_PASS_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_EPIPHANY_PASS_INFO, SeahorseGkrEpiphanyPassInfo))
#define SEAHORSE_GKR_EPIPHANY_PASS_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_EPIPHANY_PASS_INFO, SeahorseGkrEpiphanyPassInfoClass))
#define SEAHORSE_GKR_IS_EPIPHANY_PASS_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_EPIPHANY_PASS_INFO))
#define SEAHORSE_GKR_IS_EPIPHANY_PASS_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_EPIPHANY_PASS_INFO))
#define SEAHORSE_GKR_EPIPHANY_PASS_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_EPIPHANY_PASS_INFO, SeahorseGkrEpiphanyPassInfoClass))

typedef struct _SeahorseGkrEpiphanyPassInfo SeahorseGkrEpiphanyPassInfo;
typedef struct _SeahorseGkrEpiphanyPassInfoClass SeahorseGkrEpiphanyPassInfoClass;
typedef struct _SeahorseGkrEpiphanyPassInfoPrivate SeahorseGkrEpiphanyPassInfoPrivate;

#define SEAHORSE_GKR_TYPE_CHROME_PASS_INFO (seahorse_gkr_chrome_pass_info_get_type ())
#define SEAHORSE_GKR_CHROME_PASS_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_CHROME_PASS_INFO, SeahorseGkrChromePassInfo))
#define SEAHORSE_GKR_CHROME_PASS_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_CHROME_PASS_INFO, SeahorseGkrChromePassInfoClass))
#define SEAHORSE_GKR_IS_CHROME_PASS_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_CHROME_PASS_INFO))
#define SEAHORSE_GKR_IS_CHROME_PASS_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_CHROME_PASS_INFO))
#define SEAHORSE_GKR_CHROME_PASS_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_CHROME_PASS_INFO, SeahorseGkrChromePassInfoClass))

typedef struct _SeahorseGkrChromePassInfo SeahorseGkrChromePassInfo;
typedef struct _SeahorseGkrChromePassInfoClass SeahorseGkrChromePassInfoClass;
typedef struct _SeahorseGkrChromePassInfoPrivate SeahorseGkrChromePassInfoPrivate;

#define SEAHORSE_GKR_TYPE_EMPATHY_INFO (seahorse_gkr_empathy_info_get_type ())
#define SEAHORSE_GKR_EMPATHY_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_EMPATHY_INFO, SeahorseGkrEmpathyInfo))
#define SEAHORSE_GKR_EMPATHY_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_EMPATHY_INFO, SeahorseGkrEmpathyInfoClass))
#define SEAHORSE_GKR_IS_EMPATHY_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_EMPATHY_INFO))
#define SEAHORSE_GKR_IS_EMPATHY_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_EMPATHY_INFO))
#define SEAHORSE_GKR_EMPATHY_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_EMPATHY_INFO, SeahorseGkrEmpathyInfoClass))

typedef struct _SeahorseGkrEmpathyInfo SeahorseGkrEmpathyInfo;
typedef struct _SeahorseGkrEmpathyInfoClass SeahorseGkrEmpathyInfoClass;
typedef struct _SeahorseGkrEmpathyInfoPrivate SeahorseGkrEmpathyInfoPrivate;

#define SEAHORSE_GKR_TYPE_TELEPATHY_INFO (seahorse_gkr_telepathy_info_get_type ())
#define SEAHORSE_GKR_TELEPATHY_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_TELEPATHY_INFO, SeahorseGkrTelepathyInfo))
#define SEAHORSE_GKR_TELEPATHY_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_TELEPATHY_INFO, SeahorseGkrTelepathyInfoClass))
#define SEAHORSE_GKR_IS_TELEPATHY_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_TELEPATHY_INFO))
#define SEAHORSE_GKR_IS_TELEPATHY_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_TELEPATHY_INFO))
#define SEAHORSE_GKR_TELEPATHY_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_TELEPATHY_INFO, SeahorseGkrTelepathyInfoClass))

typedef struct _SeahorseGkrTelepathyInfo SeahorseGkrTelepathyInfo;
typedef struct _SeahorseGkrTelepathyInfoClass SeahorseGkrTelepathyInfoClass;
typedef struct _SeahorseGkrTelepathyInfoPrivate SeahorseGkrTelepathyInfoPrivate;

#define SEAHORSE_GKR_TYPE_GOA_INFO (seahorse_gkr_goa_info_get_type ())
#define SEAHORSE_GKR_GOA_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_GOA_INFO, SeahorseGkrGoaInfo))
#define SEAHORSE_GKR_GOA_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_GOA_INFO, SeahorseGkrGoaInfoClass))
#define SEAHORSE_GKR_IS_GOA_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_GOA_INFO))
#define SEAHORSE_GKR_IS_GOA_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_GOA_INFO))
#define SEAHORSE_GKR_GOA_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_GOA_INFO, SeahorseGkrGoaInfoClass))

typedef struct _SeahorseGkrGoaInfo SeahorseGkrGoaInfo;
typedef struct _SeahorseGkrGoaInfoClass SeahorseGkrGoaInfoClass;
typedef struct _SeahorseGkrGoaInfoPrivate SeahorseGkrGoaInfoPrivate;

#define SEAHORSE_GKR_TYPE_ITEM_PROPERTIES (seahorse_gkr_item_properties_get_type ())
#define SEAHORSE_GKR_ITEM_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_ITEM_PROPERTIES, SeahorseGkrItemProperties))
#define SEAHORSE_GKR_ITEM_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_ITEM_PROPERTIES, SeahorseGkrItemPropertiesClass))
#define SEAHORSE_GKR_IS_ITEM_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_ITEM_PROPERTIES))
#define SEAHORSE_GKR_IS_ITEM_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_ITEM_PROPERTIES))
#define SEAHORSE_GKR_ITEM_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_ITEM_PROPERTIES, SeahorseGkrItemPropertiesClass))

typedef struct _SeahorseGkrItemProperties SeahorseGkrItemProperties;
typedef struct _SeahorseGkrItemPropertiesClass SeahorseGkrItemPropertiesClass;
typedef struct _SeahorseGkrItemPropertiesPrivate SeahorseGkrItemPropertiesPrivate;

#define SEAHORSE_GKR_TYPE_ITEM (seahorse_gkr_item_get_type ())
#define SEAHORSE_GKR_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_ITEM, SeahorseGkrItem))
#define SEAHORSE_GKR_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_ITEM, SeahorseGkrItemClass))
#define SEAHORSE_GKR_IS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_ITEM))
#define SEAHORSE_GKR_IS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_ITEM))
#define SEAHORSE_GKR_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_ITEM, SeahorseGkrItemClass))

typedef struct _SeahorseGkrItem SeahorseGkrItem;
typedef struct _SeahorseGkrItemClass SeahorseGkrItemClass;
typedef enum  {
	SEAHORSE_GKR_USE_OTHER,
	SEAHORSE_GKR_USE_NETWORK,
	SEAHORSE_GKR_USE_WEB,
	SEAHORSE_GKR_USE_PGP,
	SEAHORSE_GKR_USE_SSH
} SeahorseGkrUse;

#define SEAHORSE_GKR_TYPE_USE (seahorse_gkr_use_get_type ())
typedef struct _SeahorseGkrItemPrivate SeahorseGkrItemPrivate;

#define SEAHORSE_GKR_TYPE_KEYRING_ADD (seahorse_gkr_keyring_add_get_type ())
#define SEAHORSE_GKR_KEYRING_ADD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_KEYRING_ADD, SeahorseGkrKeyringAdd))
#define SEAHORSE_GKR_KEYRING_ADD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_KEYRING_ADD, SeahorseGkrKeyringAddClass))
#define SEAHORSE_GKR_IS_KEYRING_ADD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_KEYRING_ADD))
#define SEAHORSE_GKR_IS_KEYRING_ADD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_KEYRING_ADD))
#define SEAHORSE_GKR_KEYRING_ADD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_KEYRING_ADD, SeahorseGkrKeyringAddClass))

typedef struct _SeahorseGkrKeyringAdd SeahorseGkrKeyringAdd;
typedef struct _SeahorseGkrKeyringAddClass SeahorseGkrKeyringAddClass;
typedef struct _SeahorseGkrKeyringAddPrivate SeahorseGkrKeyringAddPrivate;

#define SEAHORSE_GKR_TYPE_KEYRING_PERMISSION (seahorse_gkr_keyring_permission_get_type ())
#define SEAHORSE_GKR_KEYRING_PERMISSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_KEYRING_PERMISSION, SeahorseGkrKeyringPermission))
#define SEAHORSE_GKR_KEYRING_PERMISSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_KEYRING_PERMISSION, SeahorseGkrKeyringPermissionClass))
#define SEAHORSE_GKR_IS_KEYRING_PERMISSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_KEYRING_PERMISSION))
#define SEAHORSE_GKR_IS_KEYRING_PERMISSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_KEYRING_PERMISSION))
#define SEAHORSE_GKR_KEYRING_PERMISSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_KEYRING_PERMISSION, SeahorseGkrKeyringPermissionClass))

typedef struct _SeahorseGkrKeyringPermission SeahorseGkrKeyringPermission;
typedef struct _SeahorseGkrKeyringPermissionClass SeahorseGkrKeyringPermissionClass;
typedef struct _SeahorseGkrKeyringPermissionPrivate SeahorseGkrKeyringPermissionPrivate;

#define SEAHORSE_GKR_TYPE_KEYRING_PROPERTIES (seahorse_gkr_keyring_properties_get_type ())
#define SEAHORSE_GKR_KEYRING_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_KEYRING_PROPERTIES, SeahorseGkrKeyringProperties))
#define SEAHORSE_GKR_KEYRING_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_KEYRING_PROPERTIES, SeahorseGkrKeyringPropertiesClass))
#define SEAHORSE_GKR_IS_KEYRING_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_KEYRING_PROPERTIES))
#define SEAHORSE_GKR_IS_KEYRING_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_KEYRING_PROPERTIES))
#define SEAHORSE_GKR_KEYRING_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_KEYRING_PROPERTIES, SeahorseGkrKeyringPropertiesClass))

typedef struct _SeahorseGkrKeyringProperties SeahorseGkrKeyringProperties;
typedef struct _SeahorseGkrKeyringPropertiesClass SeahorseGkrKeyringPropertiesClass;
typedef struct _SeahorseGkrKeyringPropertiesPrivate SeahorseGkrKeyringPropertiesPrivate;
typedef struct _SeahorseGkrKeyringPrivate SeahorseGkrKeyringPrivate;

#define SEAHORSE_GKR_TYPE_PASSWORD_ENTRY (seahorse_gkr_password_entry_get_type ())
#define SEAHORSE_GKR_PASSWORD_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_GKR_TYPE_PASSWORD_ENTRY, SeahorseGkrPasswordEntry))
#define SEAHORSE_GKR_PASSWORD_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_GKR_TYPE_PASSWORD_ENTRY, SeahorseGkrPasswordEntryClass))
#define SEAHORSE_GKR_IS_PASSWORD_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_GKR_TYPE_PASSWORD_ENTRY))
#define SEAHORSE_GKR_IS_PASSWORD_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_GKR_TYPE_PASSWORD_ENTRY))
#define SEAHORSE_GKR_PASSWORD_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_GKR_TYPE_PASSWORD_ENTRY, SeahorseGkrPasswordEntryClass))

typedef struct _SeahorseGkrPasswordEntry SeahorseGkrPasswordEntry;
typedef struct _SeahorseGkrPasswordEntryClass SeahorseGkrPasswordEntryClass;
typedef struct _SeahorseGkrPasswordEntryPrivate SeahorseGkrPasswordEntryPrivate;

struct _SeahorseGkrBackend {
	GObject parent_instance;
	SeahorseGkrBackendPrivate * priv;
};

struct _SeahorseGkrBackendClass {
	GObjectClass parent_class;
};

struct _SeahorseGkrBackendActions {
	SeahorseActionGroup parent_instance;
	SeahorseGkrBackendActionsPrivate * priv;
};

struct _SeahorseGkrBackendActionsClass {
	SeahorseActionGroupClass parent_class;
};

struct _SeahorseGkrDialog {
	GTypeInstance parent_instance;
	volatile int ref_count;
	SeahorseGkrDialogPrivate * priv;
};

struct _SeahorseGkrDialogClass {
	GTypeClass parent_class;
	void (*finalize) (SeahorseGkrDialog *self);
};

struct _SeahorseGkrItemAdd {
	GtkDialog parent_instance;
	SeahorseGkrItemAddPrivate * priv;
};

struct _SeahorseGkrItemAddClass {
	GtkDialogClass parent_class;
};

struct _SeahorseGkrItemInfo {
	GObject parent_instance;
	SeahorseGkrItemInfoPrivate * priv;
};

struct _SeahorseGkrItemInfoClass {
	GObjectClass parent_class;
};

struct _SeahorseGkrNmConnectionInfo {
	SeahorseGkrItemInfo parent_instance;
	SeahorseGkrNmConnectionInfoPrivate * priv;
};

struct _SeahorseGkrNmConnectionInfoClass {
	SeahorseGkrItemInfoClass parent_class;
};

struct _SeahorseGkrGkrNetworkPassInfo {
	SeahorseGkrItemInfo parent_instance;
	SeahorseGkrGkrNetworkPassInfoPrivate * priv;
};

struct _SeahorseGkrGkrNetworkPassInfoClass {
	SeahorseGkrItemInfoClass parent_class;
};

struct _SeahorseGkrEdsPassInfo {
	SeahorseGkrItemInfo parent_instance;
	SeahorseGkrEdsPassInfoPrivate * priv;
};

struct _SeahorseGkrEdsPassInfoClass {
	SeahorseGkrItemInfoClass parent_class;
};

struct _SeahorseGkrEpiphanyPassInfo {
	SeahorseGkrItemInfo parent_instance;
	SeahorseGkrEpiphanyPassInfoPrivate * priv;
};

struct _SeahorseGkrEpiphanyPassInfoClass {
	SeahorseGkrItemInfoClass parent_class;
};

struct _SeahorseGkrChromePassInfo {
	SeahorseGkrItemInfo parent_instance;
	SeahorseGkrChromePassInfoPrivate * priv;
};

struct _SeahorseGkrChromePassInfoClass {
	SeahorseGkrItemInfoClass parent_class;
};

struct _SeahorseGkrEmpathyInfo {
	SeahorseGkrItemInfo parent_instance;
	SeahorseGkrEmpathyInfoPrivate * priv;
};

struct _SeahorseGkrEmpathyInfoClass {
	SeahorseGkrItemInfoClass parent_class;
};

struct _SeahorseGkrTelepathyInfo {
	SeahorseGkrItemInfo parent_instance;
	SeahorseGkrTelepathyInfoPrivate * priv;
};

struct _SeahorseGkrTelepathyInfoClass {
	SeahorseGkrItemInfoClass parent_class;
};

struct _SeahorseGkrGoaInfo {
	SeahorseGkrItemInfo parent_instance;
	SeahorseGkrGoaInfoPrivate * priv;
};

struct _SeahorseGkrGoaInfoClass {
	SeahorseGkrItemInfoClass parent_class;
};

struct _SeahorseGkrItemProperties {
	GtkDialog parent_instance;
	SeahorseGkrItemPropertiesPrivate * priv;
};

struct _SeahorseGkrItemPropertiesClass {
	GtkDialogClass parent_class;
};

struct _SeahorseGkrItem {
	SecretItem parent_instance;
	SeahorseGkrItemPrivate * priv;
};

struct _SeahorseGkrItemClass {
	SecretItemClass parent_class;
};

struct _SeahorseGkrKeyringAdd {
	GtkDialog parent_instance;
	SeahorseGkrKeyringAddPrivate * priv;
};

struct _SeahorseGkrKeyringAddClass {
	GtkDialogClass parent_class;
};

struct _SeahorseGkrKeyringPermission {
	GPermission parent_instance;
	SeahorseGkrKeyringPermissionPrivate * priv;
};

struct _SeahorseGkrKeyringPermissionClass {
	GPermissionClass parent_class;
};

struct _SeahorseGkrKeyringProperties {
	GtkDialog parent_instance;
	SeahorseGkrKeyringPropertiesPrivate * priv;
};

struct _SeahorseGkrKeyringPropertiesClass {
	GtkDialogClass parent_class;
};

struct _SeahorseGkrKeyring {
	SecretCollection parent_instance;
	SeahorseGkrKeyringPrivate * priv;
};

struct _SeahorseGkrKeyringClass {
	SecretCollectionClass parent_class;
};

struct _SeahorseGkrPasswordEntry {
	GtkEntry parent_instance;
	SeahorseGkrPasswordEntryPrivate * priv;
};

struct _SeahorseGkrPasswordEntryClass {
	GtkEntryClass parent_class;
};

VALA_EXTERN GType seahorse_gkr_backend_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrBackend, g_object_unref)
VALA_EXTERN void seahorse_gkr_backend_refresh_collections (SeahorseGkrBackend* self);
VALA_EXTERN void seahorse_gkr_backend_initialize (void);
VALA_EXTERN SeahorseGkrBackend* seahorse_gkr_backend_instance (void);
VALA_EXTERN GType seahorse_gkr_keyring_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrKeyring, g_object_unref)
VALA_EXTERN GList* seahorse_gkr_backend_get_keyrings (SeahorseGkrBackend* self);
VALA_EXTERN void seahorse_gkr_backend_refresh (SeahorseGkrBackend* self);
VALA_EXTERN gboolean seahorse_gkr_backend_has_alias (SeahorseGkrBackend* self,
                                         const gchar* alias,
                                         SeahorseGkrKeyring* keyring);
VALA_EXTERN SeahorseGkrBackend* seahorse_gkr_backend_new (void);
VALA_EXTERN SeahorseGkrBackend* seahorse_gkr_backend_construct (GType object_type);
VALA_EXTERN GHashTable* seahorse_gkr_backend_get_aliases (SeahorseGkrBackend* self);
VALA_EXTERN SecretService* seahorse_gkr_backend_get_service (SeahorseGkrBackend* self);
VALA_EXTERN GType seahorse_gkr_backend_actions_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrBackendActions, g_object_unref)
VALA_EXTERN SeahorseActionGroup* seahorse_gkr_backend_actions_instance (SeahorseGkrBackend* backend);
VALA_EXTERN SeahorseGkrBackend* seahorse_gkr_backend_actions_get_backend (SeahorseGkrBackendActions* self);
VALA_EXTERN gpointer seahorse_gkr_dialog_ref (gpointer instance);
VALA_EXTERN void seahorse_gkr_dialog_unref (gpointer instance);
VALA_EXTERN GParamSpec* seahorse_gkr_param_spec_dialog (const gchar* name,
                                            const gchar* nick,
                                            const gchar* blurb,
                                            GType object_type,
                                            GParamFlags flags);
VALA_EXTERN void seahorse_gkr_value_set_dialog (GValue* value,
                                    gpointer v_object);
VALA_EXTERN void seahorse_gkr_value_take_dialog (GValue* value,
                                     gpointer v_object);
VALA_EXTERN gpointer seahorse_gkr_value_get_dialog (const GValue* value);
VALA_EXTERN GType seahorse_gkr_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrDialog, seahorse_gkr_dialog_unref)
VALA_EXTERN GCancellable* seahorse_gkr_dialog_begin_request (GtkWidget* dialog);
VALA_EXTERN void seahorse_gkr_dialog_complete_request (GtkWidget* dialog,
                                           gboolean cancel);
VALA_EXTERN SeahorseGkrDialog* seahorse_gkr_dialog_new (void);
VALA_EXTERN SeahorseGkrDialog* seahorse_gkr_dialog_construct (GType object_type);
VALA_EXTERN GType seahorse_gkr_item_add_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrItemAdd, g_object_unref)
VALA_EXTERN SeahorseGkrItemAdd* seahorse_gkr_item_add_new (GtkWindow* parent);
VALA_EXTERN SeahorseGkrItemAdd* seahorse_gkr_item_add_construct (GType object_type,
                                                     GtkWindow* parent);
VALA_EXTERN GType seahorse_gkr_item_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrItemInfo, g_object_unref)
VALA_EXTERN SeahorseGkrItemInfo* seahorse_gkr_item_info_new (const gchar* label,
                                                 GHashTable* attrs,
                                                 const gchar* description);
VALA_EXTERN SeahorseGkrItemInfo* seahorse_gkr_item_info_construct (GType object_type,
                                                       const gchar* label,
                                                       GHashTable* attrs,
                                                       const gchar* description);
VALA_EXTERN void seahorse_gkr_item_info_query_installed_apps (SeahorseGkrItemInfo* self,
                                                  const gchar* item_type);
VALA_EXTERN const gchar* seahorse_gkr_item_info_get_attribute_string (SeahorseGkrItemInfo* self,
                                                          GHashTable* attrs,
                                                          const gchar* name);
VALA_EXTERN gint seahorse_gkr_item_info_get_attribute_int (SeahorseGkrItemInfo* self,
                                               GHashTable* attrs,
                                               const gchar* name);
VALA_EXTERN const gchar* seahorse_gkr_item_info_get_label (SeahorseGkrItemInfo* self);
VALA_EXTERN void seahorse_gkr_item_info_set_label (SeahorseGkrItemInfo* self,
                                       const gchar* value);
VALA_EXTERN const gchar* seahorse_gkr_item_info_get_description (SeahorseGkrItemInfo* self);
VALA_EXTERN void seahorse_gkr_item_info_set_description (SeahorseGkrItemInfo* self,
                                             const gchar* value);
VALA_EXTERN const gchar* seahorse_gkr_item_info_get_details (SeahorseGkrItemInfo* self);
VALA_EXTERN void seahorse_gkr_item_info_set_details (SeahorseGkrItemInfo* self,
                                         const gchar* value);
VALA_EXTERN GIcon* seahorse_gkr_item_info_get_icon (SeahorseGkrItemInfo* self);
VALA_EXTERN void seahorse_gkr_item_info_set_icon (SeahorseGkrItemInfo* self,
                                      GIcon* value);
VALA_EXTERN GType seahorse_gkr_nm_connection_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrNmConnectionInfo, g_object_unref)
VALA_EXTERN SeahorseGkrNmConnectionInfo* seahorse_gkr_nm_connection_info_new (const gchar* label,
                                                                  GHashTable* attrs);
VALA_EXTERN SeahorseGkrNmConnectionInfo* seahorse_gkr_nm_connection_info_construct (GType object_type,
                                                                        const gchar* label,
                                                                        GHashTable* attrs);
VALA_EXTERN GType seahorse_gkr_gkr_network_pass_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrGkrNetworkPassInfo, g_object_unref)
VALA_EXTERN SeahorseGkrGkrNetworkPassInfo* seahorse_gkr_gkr_network_pass_info_new (const gchar* label,
                                                                       GHashTable* attrs);
VALA_EXTERN SeahorseGkrGkrNetworkPassInfo* seahorse_gkr_gkr_network_pass_info_construct (GType object_type,
                                                                             const gchar* label,
                                                                             GHashTable* attrs);
VALA_EXTERN GType seahorse_gkr_eds_pass_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrEdsPassInfo, g_object_unref)
VALA_EXTERN SeahorseGkrEdsPassInfo* seahorse_gkr_eds_pass_info_new (const gchar* label,
                                                        GHashTable* attrs);
VALA_EXTERN SeahorseGkrEdsPassInfo* seahorse_gkr_eds_pass_info_construct (GType object_type,
                                                              const gchar* label,
                                                              GHashTable* attrs);
VALA_EXTERN GType seahorse_gkr_epiphany_pass_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrEpiphanyPassInfo, g_object_unref)
VALA_EXTERN SeahorseGkrEpiphanyPassInfo* seahorse_gkr_epiphany_pass_info_new (const gchar* label,
                                                                  GHashTable* attrs);
VALA_EXTERN SeahorseGkrEpiphanyPassInfo* seahorse_gkr_epiphany_pass_info_construct (GType object_type,
                                                                        const gchar* label,
                                                                        GHashTable* attrs);
VALA_EXTERN GType seahorse_gkr_chrome_pass_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrChromePassInfo, g_object_unref)
VALA_EXTERN SeahorseGkrChromePassInfo* seahorse_gkr_chrome_pass_info_new (const gchar* label,
                                                              GHashTable* attrs);
VALA_EXTERN SeahorseGkrChromePassInfo* seahorse_gkr_chrome_pass_info_construct (GType object_type,
                                                                    const gchar* label,
                                                                    GHashTable* attrs);
VALA_EXTERN GType seahorse_gkr_empathy_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrEmpathyInfo, g_object_unref)
VALA_EXTERN SeahorseGkrEmpathyInfo* seahorse_gkr_empathy_info_new (const gchar* label,
                                                       GHashTable* attrs);
VALA_EXTERN SeahorseGkrEmpathyInfo* seahorse_gkr_empathy_info_construct (GType object_type,
                                                             const gchar* label,
                                                             GHashTable* attrs);
VALA_EXTERN GType seahorse_gkr_telepathy_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrTelepathyInfo, g_object_unref)
VALA_EXTERN SeahorseGkrTelepathyInfo* seahorse_gkr_telepathy_info_new (const gchar* label,
                                                           GHashTable* attrs);
VALA_EXTERN SeahorseGkrTelepathyInfo* seahorse_gkr_telepathy_info_construct (GType object_type,
                                                                 const gchar* label,
                                                                 GHashTable* attrs);
VALA_EXTERN gchar* seahorse_gkr_telepathy_info_decode_id (const gchar* account);
VALA_EXTERN GType seahorse_gkr_goa_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrGoaInfo, g_object_unref)
VALA_EXTERN SeahorseGkrGoaInfo* seahorse_gkr_goa_info_new (const gchar* label,
                                               GHashTable* attrs);
VALA_EXTERN SeahorseGkrGoaInfo* seahorse_gkr_goa_info_construct (GType object_type,
                                                     const gchar* label,
                                                     GHashTable* attrs);
VALA_EXTERN GType seahorse_gkr_item_properties_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrItemProperties, g_object_unref)
VALA_EXTERN GType seahorse_gkr_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrItem, g_object_unref)
VALA_EXTERN SeahorseGkrItemProperties* seahorse_gkr_item_properties_new (SeahorseGkrItem* item,
                                                             GtkWindow* parent);
VALA_EXTERN SeahorseGkrItemProperties* seahorse_gkr_item_properties_construct (GType object_type,
                                                                   SeahorseGkrItem* item,
                                                                   GtkWindow* parent);
VALA_EXTERN SeahorseGkrItem* seahorse_gkr_item_properties_get_item (SeahorseGkrItemProperties* self);
VALA_EXTERN GType seahorse_gkr_use_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void seahorse_gkr_item_refresh (SeahorseGkrItem* self);
VALA_EXTERN SecretValue* seahorse_gkr_item_get_secret (SeahorseGkrItem* self);
VALA_EXTERN gchar* seahorse_gkr_item_get_attribute (SeahorseGkrItem* self,
                                        const gchar* name);
VALA_EXTERN void seahorse_gkr_item_set_secret (SeahorseGkrItem* self,
                                   SecretValue* value,
                                   GCancellable* cancellable,
                                   GAsyncReadyCallback _callback_,
                                   gpointer _user_data_);
VALA_EXTERN gboolean seahorse_gkr_item_set_secret_finish (SeahorseGkrItem* self,
                                              GAsyncResult* _res_,
                                              GError** error);
VALA_EXTERN void seahorse_gkr_item_copy_secret_to_clipboard (SeahorseGkrItem* self,
                                                 GtkClipboard* clipboard,
                                                 GAsyncReadyCallback _callback_,
                                                 gpointer _user_data_);
VALA_EXTERN void seahorse_gkr_item_copy_secret_to_clipboard_finish (SeahorseGkrItem* self,
                                                        GAsyncResult* _res_,
                                                        GError** error);
VALA_EXTERN SeahorseGkrItem* seahorse_gkr_item_new (void);
VALA_EXTERN SeahorseGkrItem* seahorse_gkr_item_construct (GType object_type);
VALA_EXTERN gchar* seahorse_gkr_item_get_description (SeahorseGkrItem* self);
VALA_EXTERN SeahorseGkrUse seahorse_gkr_item_get_use (SeahorseGkrItem* self);
VALA_EXTERN gboolean seahorse_gkr_item_get_has_secret (SeahorseGkrItem* self);
VALA_EXTERN SeahorseGkrKeyring* seahorse_gkr_item_get_place (SeahorseGkrItem* self);
VALA_EXTERN void seahorse_gkr_item_set_place (SeahorseGkrItem* self,
                                  SeahorseGkrKeyring* value);
VALA_EXTERN SeahorseFlags seahorse_gkr_item_get_object_flags (SeahorseGkrItem* self);
VALA_EXTERN GIcon* seahorse_gkr_item_get_icon (SeahorseGkrItem* self);
VALA_EXTERN gchar* seahorse_gkr_item_get_label (SeahorseGkrItem* self);
VALA_EXTERN gchar* seahorse_gkr_item_get_markup (SeahorseGkrItem* self);
VALA_EXTERN SeahorseUsage seahorse_gkr_item_get_usage (SeahorseGkrItem* self);
VALA_EXTERN GType seahorse_gkr_keyring_add_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrKeyringAdd, g_object_unref)
VALA_EXTERN SeahorseGkrKeyringAdd* seahorse_gkr_keyring_add_new (GtkWindow* parent);
VALA_EXTERN SeahorseGkrKeyringAdd* seahorse_gkr_keyring_add_construct (GType object_type,
                                                           GtkWindow* parent);
VALA_EXTERN GType seahorse_gkr_keyring_permission_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrKeyringPermission, g_object_unref)
VALA_EXTERN SeahorseGkrKeyringPermission* seahorse_gkr_keyring_permission_new (SeahorseGkrKeyring* keyring);
VALA_EXTERN SeahorseGkrKeyringPermission* seahorse_gkr_keyring_permission_construct (GType object_type,
                                                                         SeahorseGkrKeyring* keyring);
VALA_EXTERN GType seahorse_gkr_keyring_properties_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrKeyringProperties, g_object_unref)
VALA_EXTERN SeahorseGkrKeyringProperties* seahorse_gkr_keyring_properties_new (SeahorseGkrKeyring* keyring,
                                                                   GtkWindow* parent);
VALA_EXTERN SeahorseGkrKeyringProperties* seahorse_gkr_keyring_properties_construct (GType object_type,
                                                                         SeahorseGkrKeyring* keyring,
                                                                         GtkWindow* parent);
VALA_EXTERN SeahorseGkrKeyring* seahorse_gkr_keyring_properties_get_keyring (SeahorseGkrKeyringProperties* self);
VALA_EXTERN void seahorse_gkr_keyring_on_action_set_default (SeahorseGkrKeyring* self,
                                                 GSimpleAction* action,
                                                 GVariant* param);
VALA_EXTERN void seahorse_gkr_keyring_set_as_default (SeahorseGkrKeyring* self);
VALA_EXTERN void seahorse_gkr_keyring_on_action_change_password (SeahorseGkrKeyring* self,
                                                     GSimpleAction* action,
                                                     GVariant* param);
VALA_EXTERN void seahorse_gkr_keyring_change_password (SeahorseGkrKeyring* self);
VALA_EXTERN SeahorseGkrKeyring* seahorse_gkr_keyring_new (void);
VALA_EXTERN SeahorseGkrKeyring* seahorse_gkr_keyring_construct (GType object_type);
VALA_EXTERN gboolean seahorse_gkr_keyring_get_is_default (SeahorseGkrKeyring* self);
VALA_EXTERN GType seahorse_gkr_password_entry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeahorseGkrPasswordEntry, g_object_unref)
VALA_EXTERN SeahorseGkrPasswordEntry* seahorse_gkr_password_entry_new (void);
VALA_EXTERN SeahorseGkrPasswordEntry* seahorse_gkr_password_entry_construct (GType object_type);
VALA_EXTERN void seahorse_gkr_password_entry_set_initial_password (SeahorseGkrPasswordEntry* self,
                                                       const gchar* password);
VALA_EXTERN gboolean seahorse_gkr_password_entry_get_has_changed (SeahorseGkrPasswordEntry* self);
VALA_EXTERN void seahorse_gkr_password_entry_set_has_changed (SeahorseGkrPasswordEntry* self,
                                                  gboolean value);

G_END_DECLS

#endif
