/* icons.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from icons.vala, do not modify */

/*
 * Seahorse
 *
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 * Author: Stef Walter <stefw@collabora.co.uk>
 */

#include "seahorse-common.h"
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include "config.h"
#include <gtk/gtk.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

#define _g_free0(var) (var = (g_free (var), NULL))

gboolean seahorse__icons_inited = FALSE;

void
seahorse_icons_init (void)
{
	gchar* path = NULL;
	gchar* _tmp0_;
	GtkIconTheme* _tmp1_;
	const gchar* _tmp2_;
	if (seahorse__icons_inited) {
		return;
	}
	seahorse__icons_inited = TRUE;
	_tmp0_ = g_build_filename (PKGDATADIR, "icons", NULL);
	path = _tmp0_;
	_tmp1_ = gtk_icon_theme_get_default ();
	_tmp2_ = path;
	gtk_icon_theme_append_search_path (_tmp1_, _tmp2_);
	gtk_window_set_default_icon_name (APPLICATION_ID);
	_g_free0 (path);
}

