/* prefs.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from prefs.vala, do not modify */

/*
 * Seahorse
 *
 * Copyright (C) 2004-2005 Stefan Walter
 * Copyright (C) 2017 Niels De Graef
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see
 * <http://www.gnu.org/licenses/>.
 */

#include "seahorse-common.h"
#include <glib-object.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gi18n-lib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	SEAHORSE_PREFS_0_PROPERTY,
	SEAHORSE_PREFS_NUM_PROPERTIES
};
static GParamSpec* seahorse_prefs_properties[SEAHORSE_PREFS_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

static gpointer seahorse_prefs_parent_class = NULL;

static GType seahorse_prefs_get_type_once (void);

/**
     * Create a new preferences window.
     *
     * @param parent The Gtk.Window to set as the preferences dialog's parent
     */
SeahorsePrefs*
seahorse_prefs_construct (GType object_type,
                          GtkWindow* parent)
{
	SeahorsePrefs * self = NULL;
	SeahorsePrefsKeyservers* _tmp0_;
	SeahorsePrefsKeyservers* _tmp1_;
	self = (SeahorsePrefs*) g_object_new (object_type, "title", _ ("Preferences"), "transient-for", parent, "search-enabled", FALSE, "modal", TRUE, NULL);
	_tmp0_ = seahorse_prefs_keyservers_new ();
	g_object_ref_sink (_tmp0_);
	_tmp1_ = _tmp0_;
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp1_);
	_g_object_unref0 (_tmp1_);
	return self;
}

SeahorsePrefs*
seahorse_prefs_new (GtkWindow* parent)
{
	return seahorse_prefs_construct (SEAHORSE_TYPE_PREFS, parent);
}

gboolean
seahorse_prefs_available (void)
{
	gboolean result;
	result = TRUE;
	return result;
}

static void
seahorse_prefs_class_init (SeahorsePrefsClass * klass,
                           gpointer klass_data)
{
	seahorse_prefs_parent_class = g_type_class_peek_parent (klass);
}

static void
seahorse_prefs_instance_init (SeahorsePrefs * self,
                              gpointer klass)
{
}

 G_GNUC_NO_INLINE static GType
seahorse_prefs_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SeahorsePrefsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) seahorse_prefs_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SeahorsePrefs), 0, (GInstanceInitFunc) seahorse_prefs_instance_init, NULL };
	GType seahorse_prefs_type_id;
	seahorse_prefs_type_id = g_type_register_static (hdy_preferences_window_get_type (), "SeahorsePrefs", &g_define_type_info, 0);
	return seahorse_prefs_type_id;
}

GType
seahorse_prefs_get_type (void)
{
	static volatile gsize seahorse_prefs_type_id__once = 0;
	if (g_once_init_enter (&seahorse_prefs_type_id__once)) {
		GType seahorse_prefs_type_id;
		seahorse_prefs_type_id = seahorse_prefs_get_type_once ();
		g_once_init_leave (&seahorse_prefs_type_id__once, seahorse_prefs_type_id);
	}
	return seahorse_prefs_type_id__once;
}

