/* validity.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from validity.vala, do not modify */

/*
 * Seahorse
 *
 * Copyright (C) 2003 Jacob Perkins
 * Copyright (C) 2017 Niels De Graef
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see
 * <http://www.gnu.org/licenses/>.
 */
/* [CCode (cname = "SeahorseValidity", cprefix = "SEAHORSE_VALIDITY_", has_type_id = false)]*/

#include "seahorse-common.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <glib/gi18n-lib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

/**
     * @return A string describing the validity.
     */
const gchar*
seahorse_validity_get_string (SeahorseValidity self)
{
	const gchar* result;
	switch (self) {
		case SEAHORSE_VALIDITY_UNKNOWN:
		{
			result = C_ ("Validity", "Unknown");
			return result;
		}
		case SEAHORSE_VALIDITY_NEVER:
		{
			result = C_ ("Validity", "Never");
			return result;
		}
		case SEAHORSE_VALIDITY_MARGINAL:
		{
			result = C_ ("Validity", "Marginal");
			return result;
		}
		case SEAHORSE_VALIDITY_FULL:
		{
			result = C_ ("Validity", "Full");
			return result;
		}
		case SEAHORSE_VALIDITY_ULTIMATE:
		{
			result = C_ ("Validity", "Ultimate");
			return result;
		}
		case SEAHORSE_VALIDITY_DISABLED:
		{
			result = C_ ("Validity", "Disabled");
			return result;
		}
		case SEAHORSE_VALIDITY_REVOKED:
		{
			result = C_ ("Validity", "Revoked");
			return result;
		}
		default:
		{
			result = NULL;
			return result;
		}
	}
}

 G_GNUC_NO_INLINE static GType
seahorse_validity_get_type_once (void)
{
	static const GEnumValue values[] = {{SEAHORSE_VALIDITY_REVOKED, "SEAHORSE_VALIDITY_REVOKED", "revoked"}, {SEAHORSE_VALIDITY_DISABLED, "SEAHORSE_VALIDITY_DISABLED", "disabled"}, {SEAHORSE_VALIDITY_NEVER, "SEAHORSE_VALIDITY_NEVER", "never"}, {SEAHORSE_VALIDITY_UNKNOWN, "SEAHORSE_VALIDITY_UNKNOWN", "unknown"}, {SEAHORSE_VALIDITY_MARGINAL, "SEAHORSE_VALIDITY_MARGINAL", "marginal"}, {SEAHORSE_VALIDITY_FULL, "SEAHORSE_VALIDITY_FULL", "full"}, {SEAHORSE_VALIDITY_ULTIMATE, "SEAHORSE_VALIDITY_ULTIMATE", "ultimate"}, {0, NULL, NULL}};
	GType seahorse_validity_type_id;
	seahorse_validity_type_id = g_enum_register_static ("SeahorseValidity", values);
	return seahorse_validity_type_id;
}

GType
seahorse_validity_get_type (void)
{
	static volatile gsize seahorse_validity_type_id__once = 0;
	if (g_once_init_enter (&seahorse_validity_type_id__once)) {
		GType seahorse_validity_type_id;
		seahorse_validity_type_id = seahorse_validity_get_type_once ();
		g_once_init_leave (&seahorse_validity_type_id__once, seahorse_validity_type_id);
	}
	return seahorse_validity_type_id__once;
}

